@@ -70,6 +70,13 @@ const struct frr_yang_module_info frr_bfdd_info = {
 				.cli_show = bfd_cli_show_passive,
                         }
                 },
+                {
+                        .xpath = "/frr-bfdd:bfdd/bfd/profile/log-session-changes",
+                        .cbs = {
+                                .modify = bfdd_bfd_profile_log_session_changes_modify,
+				.cli_show = bfd_cli_show_log_session_changes,
+                        }
+                },
 		{
 			.xpath = "/frr-bfdd:bfdd/bfd/profile/minimum-ttl",
 			.cbs = {
@@ -160,6 +167,13 @@ const struct frr_yang_module_info frr_bfdd_info = {
 				.cli_show = bfd_cli_show_passive,
 			}
 		},
+		{
+			.xpath = "/frr-bfdd:bfdd/bfd/sessions/single-hop/log-session-changes",
+			.cbs = {
+				.modify = bfdd_bfd_sessions_single_hop_log_session_changes_modify,
+				.cli_show = bfd_cli_show_log_session_changes,
+			}
+		},
 		{
 			.xpath = "/frr-bfdd:bfdd/bfd/sessions/single-hop/echo-mode",
 			.cbs = {
@@ -356,6 +370,13 @@ const struct frr_yang_module_info frr_bfdd_info = {
 				.cli_show = bfd_cli_show_passive,
 			}
 		},
+		{
+			.xpath = "/frr-bfdd:bfdd/bfd/sessions/multi-hop/log-session-changes",
+			.cbs = {
+				.modify = bfdd_bfd_sessions_single_hop_log_session_changes_modify,
+				.cli_show = bfd_cli_show_log_session_changes,
+			}
+		},
 		{
 			.xpath = "/frr-bfdd:bfdd/bfd/sessions/multi-hop/minimum-ttl",
 			.cbs = {
@@ -572,6 +593,13 @@ const struct frr_yang_module_info frr_bfdd_info = {
 				.cli_show = bfd_cli_show_passive,
 			}
 		},
+		{
+			.xpath = "/frr-bfdd:bfdd/bfd/sessions/sbfd-echo/log-session-changes",
+			.cbs = {
+				.modify = bfdd_bfd_sessions_single_hop_log_session_changes_modify,
+				.cli_show = bfd_cli_show_log_session_changes,
+			}
+		},
 		{
 			.xpath = "/frr-bfdd:bfdd/bfd/sessions/sbfd-echo/bfd-mode",
 			.cbs = {
@@ -788,6 +816,13 @@ const struct frr_yang_module_info frr_bfdd_info = {
 				.cli_show = bfd_cli_show_passive,
 			}
 		},
+		{
+			.xpath = "/frr-bfdd:bfdd/bfd/sessions/sbfd-init/log-session-changes",
+			.cbs = {
+				.modify = bfdd_bfd_sessions_single_hop_log_session_changes_modify,
+				.cli_show = bfd_cli_show_log_session_changes,
+			}
+		},
 		{
 			.xpath = "/frr-bfdd:bfdd/bfd/sessions/sbfd-init/bfd-mode",
 			.cbs = {
