@@ -43,7 +43,7 @@
  * instead moved to the end of the queue.  This ensures that the queue size is
  * bounded by the BGP table size.
  *
- * bmp_qlist is the queue itself while bmp_qhash is used to efficiently check
+ * bmp_qlist is the queue itself while bmp_rbtree is used to efficiently check
  * whether a tuple is already on the list.  The queue is maintained per
  * bmp_target.
  *
@@ -54,11 +54,11 @@
  */
 
 PREDECL_DLIST(bmp_qlist);
-PREDECL_HASH(bmp_qhash);
+PREDECL_RBTREE_UNIQ(bmp_rbtree);
 
 struct bmp_queue_entry {
 	struct bmp_qlist_item bli;
-	struct bmp_qhash_item bhi;
+	struct bmp_rbtree_item bhi;
 
 	struct prefix p;
 	uint64_t peerid;
@@ -237,10 +237,10 @@ struct bmp_targets {
 	struct event *t_stats;
 	struct bmp_session_head sessions;
 
-	struct bmp_qhash_head updhash;
+	struct bmp_rbtree_head updhash;
 	struct bmp_qlist_head updlist;
 
-	struct bmp_qhash_head locupdhash;
+	struct bmp_rbtree_head locupdhash;
 	struct bmp_qlist_head locupdlist;
 
 	struct bmp_imported_bgps_head imported_bgps;
