@@ -577,7 +577,7 @@ static const char *ecommunity_gettoken(const char *str, void *eval_ptr,
 	char buf[INET_ADDRSTRLEN + 1];
 	struct ecommunity_val *eval = (struct ecommunity_val *)eval_ptr;
 	uint64_t tmp_as = 0;
-	static const char str_color[5] = "color";
+	static const char *str_color = "color";
 	const char *ptr_color;
 	bool val_color_set = false;
 
@@ -1145,8 +1145,10 @@ bool ecommunity_has_route_target(struct ecommunity *ecom)
  *
  * Filter is added to display only ECOMMUNITY_ROUTE_TARGET in some cases.
  * 0 value displays all.
+ * Index is a unsigned integer value, and stands for the extended community list entry
+ * to display when value is not -1.
  */
-char *ecommunity_ecom2str(struct ecommunity *ecom, int format, int filter)
+static char *_ecommunity_ecom2str(struct ecommunity *ecom, int format, int filter, int index)
 {
 	uint32_t i;
 	uint8_t *pnt;
@@ -1168,8 +1170,10 @@ char *ecommunity_ecom2str(struct ecommunity *ecom, int format, int filter)
 		bool unk_ecom = false;
 		memset(encbuf, 0x00, sizeof(encbuf));
 
+		if (index != -1 && (uint32_t)index != i)
+			continue;
 		/* Space between each value.  */
-		if (i > 0)
+		if (index == -1 && i > 0)
 			strlcat(str_buf, " ", str_size);
 
 		/* Retrieve value field */
@@ -1337,6 +1341,31 @@ char *ecommunity_ecom2str(struct ecommunity *ecom, int format, int filter)
 					snprintf(encbuf, sizeof(encbuf),
 						 "DF: (alg: %u, pref: %u)", alg,
 						 pref);
+			} else if (*pnt == ECOMMUNITY_EVPN_SUBTYPE_LAYER2_ATTR) {
+				uint16_t flags, l2mtu;
+
+				++pnt;
+				memcpy(&flags, pnt, 2);
+				++pnt;
+				++pnt;
+
+				memcpy(&l2mtu, pnt, 2);
+
+				snprintf(encbuf, sizeof(encbuf),
+					 "L2: P flag:%c, B Flag %c, C word %c, MTU %d",
+					 CHECK_FLAG(flags,
+						    ECOMMUNITY_EVPN_SUBTYPE_LAYER2_ATTR_PRIMARY_PE_FLAG)
+						 ? 'Y'
+						 : 'N',
+					 CHECK_FLAG(flags,
+						    ECOMMUNITY_EVPN_SUBTYPE_LAYER2_ATTR_BACKUP_PE_FLAG)
+						 ? 'Y'
+						 : 'N',
+					 CHECK_FLAG(flags,
+						    ECOMMUNITY_EVPN_SUBTYPE_LAYER2_ATTR_CONTROL_WORD_FLAG)
+						 ? 'Y'
+						 : 'N',
+					 l2mtu);
 			} else
 				unk_ecom = true;
 		} else if (type == ECOMMUNITY_ENCODE_REDIRECT_IP_NH) {
@@ -1412,14 +1441,14 @@ char *ecommunity_ecom2str(struct ecommunity *ecom, int format, int filter)
 				snprintf(encbuf, sizeof(encbuf), "FS:action %s",
 					 action);
 			} else if (sub_type == ECOMMUNITY_TRAFFIC_RATE) {
-				union traffic_rate data;
+				union traffic_rate rate;
 
-				data.rate_byte[3] = *(pnt+2);
-				data.rate_byte[2] = *(pnt+3);
-				data.rate_byte[1] = *(pnt+4);
-				data.rate_byte[0] = *(pnt+5);
+				rate.rate_byte[3] = *(pnt + 2);
+				rate.rate_byte[2] = *(pnt + 3);
+				rate.rate_byte[1] = *(pnt + 4);
+				rate.rate_byte[0] = *(pnt + 5);
 				snprintf(encbuf, sizeof(encbuf), "FS:rate %f",
-					 data.rate_float);
+					 rate.rate_float);
 			} else if (sub_type == ECOMMUNITY_TRAFFIC_MARKING) {
 				snprintf(encbuf, sizeof(encbuf),
 					 "FS:marking %u", *(pnt + 5));
@@ -1446,7 +1475,7 @@ char *ecommunity_ecom2str(struct ecommunity *ecom, int format, int filter)
 					 (color_type & 0x2) >> 1, color_type & 0x1, color);
 			} else
 				unk_ecom = true;
-		} else if (CHECK_FLAG(type, ECOMMUNITY_ENCODE_IP_NON_TRANS)) {
+		} else if (type == ECOMMUNITY_ENCODE_IP_NON_TRANS) {
 			sub_type = *pnt++;
 			if (sub_type == ECOMMUNITY_NODE_TARGET)
 				ecommunity_node_target_str(
@@ -1471,6 +1500,29 @@ unknown:
 	return str_buf;
 }
 
+char *ecommunity_ecom2str(struct ecommunity *ecom, int format, int filter)
+{
+	return _ecommunity_ecom2str(ecom, format, filter, -1);
+}
+
+char *ecommunity_ecom2str_one(struct ecommunity *ecom, int format, int number)
+{
+	return _ecommunity_ecom2str(ecom, format, 0, number);
+}
+
+bool ecommunity_include_one(struct ecommunity *ecom, uint8_t *ptr)
+{
+	uint32_t i;
+	uint8_t *ecom_ptr;
+
+	for (i = 0; i < ecom->size; i++) {
+		ecom_ptr = ecom->val + (i * ecom->unit_size);
+		if (memcmp(ptr, ecom_ptr, ecom->unit_size) == 0)
+			return true;
+	}
+	return false;
+}
+
 bool ecommunity_include(struct ecommunity *e1, struct ecommunity *e2)
 {
 	uint32_t i, j;
@@ -1612,7 +1664,7 @@ bool ecommunity_strip(struct ecommunity *ecom, uint8_t type,
 static bool ecommunity_non_transitive(uint8_t type)
 {
 	return (CHECK_FLAG(type, ECOMMUNITY_FLAG_NON_TRANSITIVE) ||
-		CHECK_FLAG(type, ECOMMUNITY_ENCODE_IP_NON_TRANS) ||
+		type == ECOMMUNITY_ENCODE_IP_NON_TRANS ||
 		type == ECOMMUNITY_ENCODE_OPAQUE_NON_TRANS);
 }
 
@@ -1660,6 +1712,46 @@ bool ecommunity_strip_non_transitive(struct ecommunity *ecom)
 	return true;
 }
 
+/*
+ * Filter source Extended Communities Attribute. May return NULL if the result
+ * is empty, or the source ecommunity, if not modified.
+ */
+struct ecommunity *ecommunity_filter(struct ecommunity *ecom,
+				     bool (*filter)(uint8_t *, uint8_t, void *), void *arg)
+{
+	struct ecommunity *new;
+	uint8_t *new_val, *p, *q;
+	uint32_t c, new_size;
+
+	if (!ecom || !ecom->size)
+		return NULL;
+
+	new_val = XMALLOC(MTYPE_ECOMMUNITY_VAL, ecom->size * ecom->unit_size);
+	new_size = 0;
+	for (c = 0, p = ecom->val, q = new_val; c < ecom->size; c++, p += ecom->unit_size) {
+		if (filter(p, ecom->unit_size, arg)) {
+			memcpy(q, p, ecom->unit_size);
+			q += ecom->unit_size;
+			new_size++;
+		}
+	}
+	if (!new_size) {
+		XFREE(MTYPE_ECOMMUNITY_VAL, new_val);
+		return NULL;
+	}
+	if (new_size == ecom->size) {
+		XFREE(MTYPE_ECOMMUNITY_VAL, new_val);
+		return ecom;
+	}
+
+	new = XCALLOC(MTYPE_ECOMMUNITY, sizeof(struct ecommunity));
+	new->size = new_size;
+	new->unit_size = ecom->unit_size;
+	new->val = new_val;
+
+	return new;
+}
+
 /*
  * Remove specified extended community value from extended community.
  * Returns 1 if value was present (and hence, removed), 0 otherwise.
