@@ -37,7 +37,15 @@ extern void bgp_lp_init(struct event_loop *master, struct labelpool *pool);
 extern void bgp_lp_finish(void);
 extern void bgp_lp_get(int type, void *labelid, vrf_id_t vrf_id,
 		       int (*cbfunc)(mpls_label_t label, void *labelid, bool allocated));
-extern void bgp_lp_release(int type, void *labelid, mpls_label_t label);
+
+struct bgp_dest;
+void bgp_lu_lp_release(struct bgp_dest *dest, mpls_label_t label);
+struct vpn_policy;
+void bgp_vpn_lp_release(struct vpn_policy *policy, mpls_label_t label);
+struct bgp_mplsvpn_nh_label_bind_cache;
+void bgp_vpn_nh_lp_release(struct bgp_mplsvpn_nh_label_bind_cache *bmnc,
+			   mpls_label_t label);
+
 extern void bgp_lp_event_chunk(uint32_t first, uint32_t last);
 extern void bgp_lp_event_zebra_down(void);
 extern void bgp_lp_event_zebra_up(void);
