@@ -136,4 +136,10 @@ DECLARE_MTYPE(BGP_SOFT_VERSION);
 
 DECLARE_MTYPE(BGP_EVPN_OVERLAY);
 
+DECLARE_MTYPE(BGP_NHC);
+DECLARE_MTYPE(BGP_NHC_TLV);
+DECLARE_MTYPE(BGP_NHC_TLV_VAL);
+
+DECLARE_MTYPE(CLEARING_BATCH);
+
 #endif /* _QUAGGA_BGP_MEMORY_H */
