@@ -101,7 +101,7 @@ inline struct bgp_dest *bgp_dest_unlock_node(struct bgp_dest *dest)
  * bgp_node_destroy
  */
 static void bgp_node_destroy(route_table_delegate_t *delegate,
-							struct route_table *table, struct route_node *node)
+			     struct route_table *table, struct route_node *node)
 {
 	struct bgp_dest *dest;
 	struct bgp_table *rt;
@@ -110,13 +110,16 @@ static void bgp_node_destroy(route_table_delegate_t *delegate,
 	if (dest) {
 		if (rt->bgp) {
 			bgp_addpath_free_node_data(&rt->bgp->tx_addpath,
-										&dest->tx_addpath,
-										rt->afi, rt->safi);
+						   &dest->tx_addpath,
+						   rt->afi, rt->safi);
 		}
 		XFREE(MTYPE_BGP_NODE, dest);
 		node->info = NULL;
 	}
 
+	if (node->p.family == AF_FLOWSPEC)
+		prefix_flowspec_ptr_free(&node->p);
+
 	XFREE(MTYPE_ROUTE_NODE, node);
 }
 
@@ -239,7 +242,11 @@ static ssize_t printfrr_bd(struct fbuf *buf, struct printfrr_eargs *ea,
 	if (!dest)
 		return bputs(buf, "(null)");
 
+#if !defined(DEV_BUILD)
 	/* need to get the real length even if buffer too small */
 	prefix2str(p, cbuf, sizeof(cbuf));
 	return bputs(buf, cbuf);
+#else
+	return bprintfrr(buf, "%s(%p)", prefix2str(p, cbuf, sizeof(cbuf)), dest);
+#endif
 }
