@@ -1,21 +1,8 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
 /*
  *
  * Copyright 2009-2016, LabN Consulting, L.L.C.
  *
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; see the file COPYING; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #ifndef QUAGGA_HGP_RFAPI_MONITOR_H
@@ -38,7 +25,7 @@ struct rfapi_monitor_vpn {
 #define RFAPI_MON_FLAG_NEEDCALLBACK	0x00000001      /* deferred callback */
 
 	// int				dcount;	/* debugging counter */
-	struct thread *timer;
+	struct event *timer;
 };
 
 struct rfapi_monitor_encap {
@@ -54,7 +41,7 @@ struct rfapi_monitor_eth {
 	struct rfapi_descriptor *rfd;   /* which NVE requested the route */
 	struct ethaddr macaddr;
 	uint32_t logical_net_id;
-	struct thread *timer;
+	struct event *timer;
 };
 
 /*
