@@ -95,10 +95,10 @@ static void encap_attr_export_ce(struct attr *new, struct attr *orig,
 	 *
 	 *          neighbor NEIGHBOR attribute-unchanged med
 	 */
-	if (!CHECK_FLAG(new->flag, BGP_ATTR_MULTI_EXIT_DISC)) {
+	if (!CHECK_FLAG(new->flag, ATTR_FLAG_BIT(BGP_ATTR_MULTI_EXIT_DISC))) {
 		uint32_t med = 255;
 
-		if (CHECK_FLAG(new->flag, BGP_ATTR_LOCAL_PREF)) {
+		if (CHECK_FLAG(new->flag, ATTR_FLAG_BIT(BGP_ATTR_LOCAL_PREF))) {
 			if (new->local_pref > 255)
 				med = 0;
 			else
@@ -642,10 +642,10 @@ encap_attr_export(struct attr *new, struct attr *orig,
 	 *
 	 *          neighbor NEIGHBOR attribute-unchanged med
 	 */
-	if (!CHECK_FLAG(new->flag, BGP_ATTR_MULTI_EXIT_DISC)) {
+	if (!CHECK_FLAG(new->flag, ATTR_FLAG_BIT(BGP_ATTR_MULTI_EXIT_DISC))) {
 		uint32_t med = 255;
 
-		if (CHECK_FLAG(new->flag, BGP_ATTR_LOCAL_PREF)) {
+		if (CHECK_FLAG(new->flag, ATTR_FLAG_BIT(BGP_ATTR_LOCAL_PREF))) {
 			if (new->local_pref > 255)
 				med = 0;
 			else
