@@ -338,13 +338,12 @@ static int process_unicast_route(struct bgp *bgp,		 /* in */
 	hattr = *attr;
 
 	if (rmap) {
-		struct bgp_path_info info;
+		struct bgp_path_info pinfo = {};
 		route_map_result_t ret;
 
-		memset(&info, 0, sizeof(info));
-		info.peer = peer;
-		info.attr = &hattr;
-		ret = route_map_apply(rmap, prefix, &info);
+		pinfo.peer = peer;
+		pinfo.attr = &hattr;
+		ret = route_map_apply(rmap, prefix, &pinfo);
 		if (ret == RMAP_DENYMATCH) {
 			bgp_attr_flush(&hattr);
 			vnc_zlog_debug_verbose(
@@ -768,13 +767,12 @@ static void vnc_import_bgp_add_route_mode_plain(struct bgp *bgp,
 	hattr = *attr;
 
 	if (rmap) {
-		struct bgp_path_info info;
+		struct bgp_path_info pinfo = {};
 		route_map_result_t ret;
 
-		memset(&info, 0, sizeof(info));
-		info.peer = peer;
-		info.attr = &hattr;
-		ret = route_map_apply(rmap, prefix, &info);
+		pinfo.peer = peer;
+		pinfo.attr = &hattr;
+		ret = route_map_apply(rmap, prefix, &pinfo);
 		if (ret == RMAP_DENYMATCH) {
 			bgp_attr_flush(&hattr);
 			vnc_zlog_debug_verbose(
