@@ -332,6 +332,7 @@ struct iface_af {
 	struct event *hello_timer;
 	uint16_t		 hello_holdtime;
 	uint16_t		 hello_interval;
+	int disable_establish_hello;
 };
 
 struct iface_ldp_sync {
@@ -739,7 +740,7 @@ struct ctl_ldp_sync {
 
 extern struct ldpd_conf		*ldpd_conf, *vty_conf;
 extern struct ldpd_global	 global;
-extern struct ldpd_init		 init;
+extern struct ldpd_init ldp_init;
 
 /* parse.y */
 struct ldpd_conf	*parse_config(char *);
