@@ -293,7 +293,7 @@ nbr_del(struct nbr *nbr)
 	nbr->auth.method = AUTH_NONE;
 
 	if (nbr_pending_connect(nbr))
-		EVENT_OFF(nbr->ev_connect);
+		event_cancel(&nbr->ev_connect);
 	nbr_stop_ktimer(nbr);
 	nbr_stop_ktimeout(nbr);
 	nbr_stop_itimeout(nbr);
@@ -420,7 +420,7 @@ nbr_start_ktimer(struct nbr *nbr)
 
 	/* send three keepalives per period */
 	secs = nbr->keepalive / KEEPALIVE_PER_PERIOD;
-	EVENT_OFF(nbr->keepalive_timer);
+	event_cancel(&nbr->keepalive_timer);
 	nbr->keepalive_timer = NULL;
 	event_add_timer(master, nbr_ktimer, nbr, secs, &nbr->keepalive_timer);
 }
@@ -428,7 +428,7 @@ nbr_start_ktimer(struct nbr *nbr)
 void
 nbr_stop_ktimer(struct nbr *nbr)
 {
-	EVENT_OFF(nbr->keepalive_timer);
+	event_cancel(&nbr->keepalive_timer);
 }
 
 /* Keepalive timeout: if the nbr hasn't sent keepalive */
@@ -447,7 +447,7 @@ static void nbr_ktimeout(struct event *thread)
 static void
 nbr_start_ktimeout(struct nbr *nbr)
 {
-	EVENT_OFF(nbr->keepalive_timeout);
+	event_cancel(&nbr->keepalive_timeout);
 	nbr->keepalive_timeout = NULL;
 	event_add_timer(master, nbr_ktimeout, nbr, nbr->keepalive,
 			&nbr->keepalive_timeout);
@@ -456,7 +456,7 @@ nbr_start_ktimeout(struct nbr *nbr)
 void
 nbr_stop_ktimeout(struct nbr *nbr)
 {
-	EVENT_OFF(nbr->keepalive_timeout);
+	event_cancel(&nbr->keepalive_timeout);
 }
 
 /* Session initialization timeout: if nbr got stuck in the initialization FSM */
@@ -476,7 +476,7 @@ nbr_start_itimeout(struct nbr *nbr)
 	int		 secs;
 
 	secs = INIT_FSM_TIMEOUT;
-	EVENT_OFF(nbr->init_timeout);
+	event_cancel(&nbr->init_timeout);
 	nbr->init_timeout = NULL;
 	event_add_timer(master, nbr_itimeout, nbr, secs, &nbr->init_timeout);
 }
@@ -484,7 +484,7 @@ nbr_start_itimeout(struct nbr *nbr)
 void
 nbr_stop_itimeout(struct nbr *nbr)
 {
-	EVENT_OFF(nbr->init_timeout);
+	event_cancel(&nbr->init_timeout);
 }
 
 /* Init delay timer: timer to retry to iniziatize session */
@@ -513,7 +513,7 @@ nbr_start_idtimer(struct nbr *nbr)
 		nbr->idtimer_cnt++;
 	}
 
-	EVENT_OFF(nbr->initdelay_timer);
+	event_cancel(&nbr->initdelay_timer);
 	nbr->initdelay_timer = NULL;
 	event_add_timer(master, nbr_idtimer, nbr, secs, &nbr->initdelay_timer);
 }
@@ -521,7 +521,7 @@ nbr_start_idtimer(struct nbr *nbr)
 void
 nbr_stop_idtimer(struct nbr *nbr)
 {
-	EVENT_OFF(nbr->initdelay_timer);
+	event_cancel(&nbr->initdelay_timer);
 }
 
 int
@@ -630,8 +630,9 @@ nbr_establish_connection(struct nbr *nbr)
 	 * an adjacency as well.
 	 */
 	RB_FOREACH(adj, nbr_adj_head, &nbr->adj_tree)
-		send_hello(adj->source.type, adj->source.link.ia,
-		    adj->source.target);
+		if (!(adj->source.type == HELLO_LINK && adj->source.link.ia->disable_establish_hello))
+			send_hello(adj->source.type, adj->source.link.ia,
+				adj->source.target);
 
 	if (connect(nbr->fd, &remote_su.sa, sockaddr_len(&remote_su.sa)) == -1) {
 		if (errno == EINPROGRESS) {
@@ -681,6 +682,18 @@ nbr_gtsm_setup(int fd, int af, struct nbr_params *nbrp)
 	if (nbrp && CHECK_FLAG(nbrp->flags, F_NBRP_GTSM_HOPS))
 		ttl = 256 - nbrp->gtsm_hops;
 
+	/*
+	 * In linux networking stack, the received mpls packets
+	 * will be processed by the host twice, one as mpls packet,
+	 * the other as ip packet, so its ttl will be decreased 1.
+	 * This behavior is based on the new kernel (5.10 and 6.1),
+	 * and older versions may behave differently.
+	 *
+	 * Here, decrease 1 for IP_MINTTL if GTSM is enabled.
+	 * And this workaround makes the GTSM mechanism a bit deviation.
+	 */
+	ttl -= 1;
+
 	switch (af) {
 	case AF_INET:
 		if (sock_set_ipv4_minttl(fd, ttl) == -1)
