@@ -11,7 +11,6 @@
 #include "base64.h"
 #include "compiler.h"
 
-static const int CHARS_PER_LINE = 72;
 static const char *ENCODING =
 	"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
 
@@ -19,7 +18,6 @@ void base64_init_encodestate(struct base64_encodestate *state_in)
 {
 	state_in->step = step_A;
 	state_in->result = 0;
-	state_in->stepcount = 0;
 }
 
 char base64_encode_value(char value_in)
@@ -76,12 +74,6 @@ int base64_encode_block(const char *plaintext_in, int length_in, char *code_out,
 				*codechar++ = base64_encode_value(result);
 				result  = (fragment & 0x03f) >> 0;
 				*codechar++ = base64_encode_value(result);
-
-				++(state_in->stepcount);
-				if (state_in->stepcount == CHARS_PER_LINE/4) {
-					*codechar++ = '\n';
-					state_in->stepcount = 0;
-				}
 		}
 	}
 	/* control should not reach here */
@@ -105,7 +97,6 @@ int base64_encode_blockend(char *code_out, struct base64_encodestate *state_in)
 	case step_A:
 		break;
 	}
-	*codechar++ = '\n';
 
 	return codechar - code_out;
 }
