@@ -14,6 +14,13 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
+#ifndef HAVE_LIBCRYPT
+#ifdef HAVE_LIBCRYPTO
+#include <openssl/des.h>
+#define crypt DES_crypt
+#endif
+#endif
+
 #include <lib/version.h>
 
 #include "command.h"
@@ -41,6 +48,7 @@
 #include "northbound_cli.h"
 #include "network.h"
 #include "routemap.h"
+#include "frregex_real.h"
 
 #include "frrscript.h"
 
@@ -482,7 +490,6 @@ static int config_write_host(struct vty *vty)
 				vty_out(vty, "enable password %s\n",
 					host.enable);
 		}
-		log_config_write(vty);
 
 		if (!cputime_enabled)
 			vty_out(vty, "no service cputime-stats\n");
@@ -2317,21 +2324,6 @@ DEFUN (no_banner_motd,
 	return CMD_SUCCESS;
 }
 
-DEFUN(allow_reserved_ranges, allow_reserved_ranges_cmd, "allow-reserved-ranges",
-      "Allow using IPv4 (Class E) reserved IP space\n")
-{
-	host.allow_reserved_ranges = true;
-	return CMD_SUCCESS;
-}
-
-DEFUN(no_allow_reserved_ranges, no_allow_reserved_ranges_cmd,
-      "no allow-reserved-ranges",
-      NO_STR "Allow using IPv4 (Class E) reserved IP space\n")
-{
-	host.allow_reserved_ranges = false;
-	return CMD_SUCCESS;
-}
-
 int cmd_find_cmds(struct vty *vty, struct cmd_token **argv, int argc)
 {
 	const struct cmd_node *node;
@@ -2597,8 +2589,6 @@ void cmd_init(int terminal)
 		install_element(CONFIG_NODE, &no_banner_motd_cmd);
 		install_element(CONFIG_NODE, &service_terminal_length_cmd);
 		install_element(CONFIG_NODE, &no_service_terminal_length_cmd);
-		install_element(CONFIG_NODE, &allow_reserved_ranges_cmd);
-		install_element(CONFIG_NODE, &no_allow_reserved_ranges_cmd);
 
 		log_cmd_init();
 		vrf_install_commands();
