@@ -7,20 +7,21 @@
  */
 
 #include <zebra.h>
-#include "lib/version.h"
-#include "routemap.h"
+#include "affinitymap.h"
 #include "filter.h"
-#include "keychain.h"
-#include "libfrr.h"
 #include "frr_pthread.h"
+#include "keychain.h"
+#include "lib/version.h"
+#include "libfrr.h"
+#include "log_vty.h"
 #include "mgmtd/mgmt.h"
 #include "mgmtd/mgmt_ds.h"
 #include "ripd/rip_nb.h"
 #include "ripngd/ripng_nb.h"
+#include "routemap.h"
 #include "routing_nb.h"
-#include "affinitymap.h"
-#include "zebra/zebra_cli.h"
 #include "srv6.h"
+#include "zebra/zebra_cli.h"
 
 /* mgmt options, we use GNU getopt library. */
 static const struct option longopts[] = {
@@ -160,12 +161,6 @@ const struct frr_yang_module_info ietf_netconf_with_defaults_info = {
  * clients into mgmtd. The modules are used by libyang in order to support
  * parsing binary data returns from the backend.
  */
-const struct frr_yang_module_info frr_backend_client_info = {
-	.name = "frr-backend",
-	.ignore_cfg_cbs = true,
-	.nodes = { { .xpath = NULL } },
-};
-
 const struct frr_yang_module_info zebra_route_map_info = {
 	.name = "frr-zebra-route-map",
 	.ignore_cfg_cbs = true,
@@ -177,9 +172,11 @@ const struct frr_yang_module_info zebra_route_map_info = {
  * MGMTd.
  */
 static const struct frr_yang_module_info *const mgmt_yang_modules[] = {
+	&frr_backend_info,
 	&frr_filter_cli_info,
 	&frr_host_cli_info,
 	&frr_interface_cli_info,
+	&frr_logging_nb_info,
 	&frr_route_map_cli_info,
 	&frr_routing_cli_info,
 	&frr_vrf_cli_info,
@@ -191,7 +188,6 @@ static const struct frr_yang_module_info *const mgmt_yang_modules[] = {
 	/*
 	 * YANG module info used by backend clients get added here.
 	 */
-	&frr_backend_client_info,
 
 	&frr_zebra_cli_info,
 	&zebra_route_map_info,
@@ -240,6 +236,8 @@ int main(int argc, char **argv)
 	int opt;
 	int buffer_size = MGMTD_SOCKET_BUF_SIZE;
 
+	frr_logging_merge_cli_to_nb_info();
+
 	frr_preinit(&mgmtd_di, argc, argv);
 	frr_opt_add("s:n" DEPRECATED_OPTIONS, longopts,
 		    "  -s, --socket_size  Set MGMTD peer socket send buffer size\n"
