@@ -1,27 +1,12 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
 /* OSPF SPF calculation.
  * Copyright (C) 1999, 2000 Kunihiro Ishiguro, Toshiaki Takada
- *
- * This file is part of GNU Zebra.
- *
- * GNU Zebra is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 2, or (at your option) any
- * later version.
- *
- * GNU Zebra is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; see the file COPYING; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
 #include <zebra.h>
 
 #include "monotime.h"
-#include "thread.h"
+#include "frrevent.h"
 #include "memory.h"
 #include "hash.h"
 #include "linklist.h"
@@ -72,8 +57,6 @@ static void ospf_spf_set_reason(ospf_spf_reason_t reason)
 	spf_reason_flags |= 1 << reason;
 }
 
-static void ospf_vertex_free(void *);
-
 /*
  * Heap related functions, for the managment of the candidates, to
  * be used with pqueue.
@@ -179,8 +162,10 @@ static struct vertex_parent *vertex_parent_new(struct vertex *v, int backlink,
 	return new;
 }
 
-static void vertex_parent_free(void *p)
+static void vertex_parent_free(struct vertex_parent *p)
 {
+	vertex_nexthop_free(p->local_nexthop);
+	vertex_nexthop_free(p->nexthop);
 	XFREE(MTYPE_OSPF_VERTEX_PARENT, p);
 }
 
@@ -203,7 +188,7 @@ static struct vertex *ospf_vertex_new(struct ospf_area *area,
 	new->lsa = lsa->data;
 	new->children = list_new();
 	new->parents = list_new();
-	new->parents->del = vertex_parent_free;
+	new->parents->del = (void (*)(void *))vertex_parent_free;
 	new->parents->cmp = vertex_parent_cmp;
 	new->lsa_p = lsa;
 
@@ -220,7 +205,7 @@ static struct vertex *ospf_vertex_new(struct ospf_area *area,
 	return new;
 }
 
-static void ospf_vertex_free(void *data)
+void ospf_vertex_free(void *data)
 {
 	struct vertex *v = data;
 
@@ -346,7 +331,7 @@ static struct vertex *ospf_spf_vertex_copy(struct vertex *vertex)
 
 	memcpy(copy, vertex, sizeof(struct vertex));
 	copy->parents = list_new();
-	copy->parents->del = vertex_parent_free;
+	copy->parents->del = (void (*)(void *))vertex_parent_free;
 	copy->parents->cmp = vertex_parent_cmp;
 	copy->children = list_new();
 
@@ -360,8 +345,7 @@ ospf_spf_vertex_parent_copy(struct vertex_parent *vertex_parent)
 	struct vertex_parent *vertex_parent_copy;
 	struct vertex_nexthop *nexthop_copy, *local_nexthop_copy;
 
-	vertex_parent_copy =
-		XCALLOC(MTYPE_OSPF_VERTEX, sizeof(struct vertex_parent));
+	vertex_parent_copy = XCALLOC(MTYPE_OSPF_VERTEX_PARENT, sizeof(struct vertex_parent));
 
 	nexthop_copy = vertex_nexthop_new();
 	local_nexthop_copy = vertex_nexthop_new();
@@ -473,6 +457,8 @@ static void ospf_spf_remove_branch(struct vertex_parent *vertex_parent,
 		listnode_delete(vertex_list, child);
 		ospf_vertex_free(child);
 	}
+
+	vertex_parent_free(vertex_parent);
 }
 
 static int ospf_spf_remove_link(struct vertex *vertex, struct list *vertex_list,
@@ -537,7 +523,7 @@ void ospf_spf_remove_resource(struct vertex *vertex, struct list *vertex_list,
 					       vertex_list);
 
 		break;
-	default:
+	case OSPF_TI_LFA_UNDEFINED_PROTECTION:
 		/* do nothing */
 		break;
 	}
@@ -683,11 +669,15 @@ static void ospf_spf_flush_parents(struct vertex *w)
 /*
  * Consider supplied next-hop for inclusion to the supplied list of
  * equal-cost next-hops, adjust list as necessary.
+ *
+ * Returns vertex parent pointer if created otherwise `NULL` if it already
+ * exists.
  */
-static void ospf_spf_add_parent(struct vertex *v, struct vertex *w,
-				struct vertex_nexthop *newhop,
-				struct vertex_nexthop *newlhop,
-				unsigned int distance)
+static struct vertex_parent *ospf_spf_add_parent(struct vertex *v,
+						 struct vertex *w,
+						 struct vertex_nexthop *newhop,
+						 struct vertex_nexthop *newlhop,
+						 unsigned int distance)
 {
 	struct vertex_parent *vp, *wp;
 	struct listnode *node;
@@ -733,7 +723,8 @@ static void ospf_spf_add_parent(struct vertex *v, struct vertex *w,
 				zlog_debug(
 					"%s: ... nexthop already on parent list, skipping add",
 					__func__);
-			return;
+
+			return NULL;
 		}
 	}
 
@@ -741,7 +732,7 @@ static void ospf_spf_add_parent(struct vertex *v, struct vertex *w,
 			       newlhop);
 	listnode_add_sort(w->parents, vp);
 
-	return;
+	return vp;
 }
 
 static int match_stub_prefix(struct lsa_header *lsa, struct in_addr v_link_addr,
@@ -979,8 +970,12 @@ static unsigned int ospf_nexthop_calculation(struct ospf_area *area,
 					memcpy(lnh, nh,
 					       sizeof(struct vertex_nexthop));
 
-					ospf_spf_add_parent(v, w, nh, lnh,
-							    distance);
+					if (ospf_spf_add_parent(v, w, nh, lnh,
+								distance) ==
+					    NULL) {
+						vertex_nexthop_free(nh);
+						vertex_nexthop_free(lnh);
+					}
 					return 1;
 				} else
 					zlog_info(
@@ -1019,8 +1014,13 @@ static unsigned int ospf_nexthop_calculation(struct ospf_area *area,
 					memcpy(lnh, nh,
 					       sizeof(struct vertex_nexthop));
 
-					ospf_spf_add_parent(v, w, nh, lnh,
-							    distance);
+					if (ospf_spf_add_parent(v, w, nh, lnh,
+								distance) ==
+					    NULL) {
+						vertex_nexthop_free(nh);
+						vertex_nexthop_free(lnh);
+					}
+
 					return 1;
 				} else
 					zlog_info(
@@ -1043,7 +1043,12 @@ static unsigned int ospf_nexthop_calculation(struct ospf_area *area,
 			lnh = vertex_nexthop_new();
 			memcpy(lnh, nh, sizeof(struct vertex_nexthop));
 
-			ospf_spf_add_parent(v, w, nh, lnh, distance);
+			if (ospf_spf_add_parent(v, w, nh, lnh, distance) ==
+			    NULL) {
+				vertex_nexthop_free(nh);
+				vertex_nexthop_free(lnh);
+			}
+
 			return 1;
 		}
 	} /* end V is the root */
@@ -1086,8 +1091,12 @@ static unsigned int ospf_nexthop_calculation(struct ospf_area *area,
 					       sizeof(struct vertex_nexthop));
 
 					added = 1;
-					ospf_spf_add_parent(v, w, nh, lnh,
-							    distance);
+					if (ospf_spf_add_parent(v, w, nh, lnh,
+								distance) ==
+					    NULL) {
+						vertex_nexthop_free(nh);
+						vertex_nexthop_free(lnh);
+					}
 				}
 				/*
 				 * Note lack of return is deliberate. See next
@@ -1148,7 +1157,13 @@ static unsigned int ospf_nexthop_calculation(struct ospf_area *area,
 			lnh = NULL;
 		}
 
-		ospf_spf_add_parent(v, w, vp->nexthop, lnh, distance);
+		nh = vertex_nexthop_new();
+		*nh = *vp->nexthop;
+
+		if (ospf_spf_add_parent(v, w, nh, lnh, distance) == NULL) {
+			vertex_nexthop_free(nh);
+			vertex_nexthop_free(lnh);
+		}
 	}
 
 	return added;
@@ -1826,9 +1841,9 @@ void ospf_spf_calculate_areas(struct ospf *ospf, struct route_table *new_table,
 }
 
 /* Worker for SPF calculation scheduler. */
-static void ospf_spf_calculate_schedule_worker(struct thread *thread)
+static void ospf_spf_calculate_schedule_worker(struct event *thread)
 {
-	struct ospf *ospf = THREAD_ARG(thread);
+	struct ospf *ospf = EVENT_ARG(thread);
 	struct route_table *new_table, *new_rtrs;
 	struct route_table *all_rtrs = NULL;
 	struct timeval start_time, spf_start_time;
@@ -1892,9 +1907,10 @@ static void ospf_spf_calculate_schedule_worker(struct thread *thread)
 	rt_time = monotime_since(&start_time, NULL);
 
 	/* Free old all routers routing table */
-	if (ospf->oall_rtrs)
-		/* ospf_route_delete (ospf->old_rtrs); */
+	if (ospf->oall_rtrs) {
 		ospf_rtrs_free(ospf->oall_rtrs);
+		ospf->oall_rtrs = NULL;
+	}
 
 	/* Update all routers routing table */
 	ospf->oall_rtrs = ospf->all_rtrs;
@@ -1904,9 +1920,10 @@ static void ospf_spf_calculate_schedule_worker(struct thread *thread)
 #endif
 
 	/* Free old ABR/ASBR routing table */
-	if (ospf->old_rtrs)
-		/* ospf_route_delete (ospf->old_rtrs); */
+	if (ospf->old_rtrs) {
 		ospf_rtrs_free(ospf->old_rtrs);
+		ospf->old_rtrs = NULL;
+	}
 
 	/* Update ABR/ASBR routing table */
 	ospf->old_rtrs = ospf->new_rtrs;
@@ -1996,7 +2013,7 @@ void ospf_spf_calculate_schedule(struct ospf *ospf, ospf_spf_reason_t reason)
 
 	elapsed = monotime_since(&ospf->ts_spf, NULL) / 1000;
 
-	ht = ospf->spf_holdtime * ospf->spf_hold_multiplier;
+	ht = (uint64_t)(ospf->spf_holdtime) * ospf->spf_hold_multiplier;
 
 	if (ht > ospf->spf_max_holdtime)
 		ht = ospf->spf_max_holdtime;
@@ -2026,8 +2043,8 @@ void ospf_spf_calculate_schedule(struct ospf *ospf, ospf_spf_reason_t reason)
 		zlog_debug("SPF: calculation timer delay = %ld msec", delay);
 
 	ospf->t_spf_calc = NULL;
-	thread_add_timer_msec(master, ospf_spf_calculate_schedule_worker, ospf,
-			      delay, &ospf->t_spf_calc);
+	event_add_timer_msec(master, ospf_spf_calculate_schedule_worker, ospf,
+			     delay, &ospf->t_spf_calc);
 }
 
 /* Restart OSPF SPF algorithm*/
