@@ -559,8 +559,7 @@ void pbr_nht_set_seq_nhg(struct pbr_map_sequence *pbrms, const char *name)
 	pbr_nht_set_seq_nhg_data(pbrms, nhgc);
 }
 
-void pbr_nht_add_individual_nexthop(struct pbr_map_sequence *pbrms,
-				    const struct nexthop *nhop)
+bool pbr_nht_add_individual_nexthop(struct pbr_map_sequence *pbrms, const struct nexthop *nhop)
 {
 	struct pbr_nexthop_group_cache *pnhgc;
 	struct pbr_nexthop_group_cache find;
@@ -569,6 +568,12 @@ void pbr_nht_add_individual_nexthop(struct pbr_map_sequence *pbrms,
 	struct nexthop *nh;
 	char buf[PBR_NHC_NAMELEN];
 
+	if (!pbr_nht_has_unallocated_table()) {
+		zlog_warn("%s: Exhausted all table identifiers; cannot create nexthop-group cache",
+			  __func__);
+		return false;
+	}
+
 	pbrms->nhg = nexthop_group_new();
 	pbrms->internal_nhg_name = XSTRDUP(
 		MTYPE_TMP,
@@ -582,18 +587,7 @@ void pbr_nht_add_individual_nexthop(struct pbr_map_sequence *pbrms,
 	nexthop_group_add_sorted(pbrms->nhg, nh);
 
 	memset(&find, 0, sizeof(find));
-	pbr_nht_nexthop_make_name(pbrms->parent->name, PBR_NHC_NAMELEN,
-				  pbrms->seqno, find.name);
-
-	if (!pbr_nht_has_unallocated_table()) {
-		zlog_warn(
-			"%s: Exhausted all table identifiers; cannot create nexthop-group cache for nexthop-group '%s'",
-			__func__, find.name);
-		return;
-	}
-
-	if (!pbrms->internal_nhg_name)
-		pbrms->internal_nhg_name = XSTRDUP(MTYPE_TMP, find.name);
+	strlcpy(find.name, pbrms->internal_nhg_name, sizeof(find.name));
 
 	pnhgc = hash_get(pbr_nhg_hash, &find, pbr_nhgc_alloc);
 
@@ -617,6 +611,8 @@ void pbr_nht_add_individual_nexthop(struct pbr_map_sequence *pbrms,
 				sizeof(pnhc->intf_name));
 	}
 	pbr_nht_install_nexthop_group(pnhgc, *pbrms->nhg);
+
+	return true;
 }
 
 static void pbr_nht_release_individual_nexthop(struct pbr_map_sequence *pbrms)
@@ -640,6 +636,7 @@ static void pbr_nht_release_individual_nexthop(struct pbr_map_sequence *pbrms)
 	hash_release(pnhgc->nhh, pnhc);
 	pbr_nh_delete(&pnhc);
 	pbr_nht_uninstall_nexthop_group(pnhgc, *pbrms->nhg, nh_type);
+	pbr_map_check_nh_group_change(pnhgc->name);
 
 	hash_release(pbr_nhg_hash, pnhgc);
 	pbr_nhgc_delete(pnhgc);
