@@ -102,7 +102,7 @@ extern void pbr_nht_set_seq_nhg_data(struct pbr_map_sequence *pbrms,
 extern void pbr_nht_set_seq_nhg(struct pbr_map_sequence *pbrms,
 				const char *name);
 
-extern void pbr_nht_add_individual_nexthop(struct pbr_map_sequence *pbrms,
+extern bool pbr_nht_add_individual_nexthop(struct pbr_map_sequence *pbrms,
 					   const struct nexthop *nhop);
 extern void pbr_nht_delete_individual_nexthop(struct pbr_map_sequence *pbrms);
 /*
