@@ -1,21 +1,9 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 /*
  * This file is part of the PCEPlib, a PCEP protocol library.
  *
  * Copyright (C) 2020 Volta Networks https://voltanet.io/
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
- *
  * Author : Brady Johnson <brady@voltanet.io>
  *
  */
@@ -48,30 +36,30 @@ void create_session_counters(pcep_session *session)
 	struct counters_subgroup *rx_msg_subgroup = create_counters_subgroup(
 		"RX Message counters", COUNTER_SUBGROUP_ID_RX_MSG,
 		PCEP_TYPE_MAX + 1);
-	create_subgroup_counter(rx_msg_subgroup, PCEP_TYPE_OPEN,
-				"Message Open");
+	create_subgroup_counter(rx_msg_subgroup, PCEP_TYPE_OPEN, "Message Open",
+				"messageOpen");
 	create_subgroup_counter(rx_msg_subgroup, PCEP_TYPE_KEEPALIVE,
-				"Message KeepAlive");
+				"Message KeepAlive", "messageKeepalive");
 	create_subgroup_counter(rx_msg_subgroup, PCEP_TYPE_PCREQ,
-				"Message PcReq");
+				"Message PcReq", "messagePcReq");
 	create_subgroup_counter(rx_msg_subgroup, PCEP_TYPE_PCREP,
-				"Message PcRep");
+				"Message PcRep", "messagePcRep");
 	create_subgroup_counter(rx_msg_subgroup, PCEP_TYPE_PCNOTF,
-				"Message Notify");
+				"Message Notify", "messageNotify");
 	create_subgroup_counter(rx_msg_subgroup, PCEP_TYPE_ERROR,
-				"Message Error");
+				"Message Error", "messageError");
 	create_subgroup_counter(rx_msg_subgroup, PCEP_TYPE_CLOSE,
-				"Message Close");
+				"Message Close", "messageClose");
 	create_subgroup_counter(rx_msg_subgroup, PCEP_TYPE_REPORT,
-				"Message Report");
+				"Message Report", "messageReport");
 	create_subgroup_counter(rx_msg_subgroup, PCEP_TYPE_UPDATE,
-				"Message Update");
+				"Message Update", "messageUpdate");
 	create_subgroup_counter(rx_msg_subgroup, PCEP_TYPE_INITIATE,
-				"Message Initiate");
+				"Message Initiate", "messageInitiate");
 	create_subgroup_counter(rx_msg_subgroup, PCEP_TYPE_START_TLS,
-				"Message StartTls");
+				"Message StartTls", "messageStartTls");
 	create_subgroup_counter(rx_msg_subgroup, PCEP_TYPE_MAX,
-				"Message Erroneous");
+				"Message Erroneous", "messageErroneous");
 
 	struct counters_subgroup *tx_msg_subgroup =
 		clone_counters_subgroup(rx_msg_subgroup, "TX Message counters",
@@ -86,59 +74,61 @@ void create_session_counters(pcep_session *session)
 	struct counters_subgroup *rx_obj_subgroup = create_counters_subgroup(
 		"RX Object counters", COUNTER_SUBGROUP_ID_RX_OBJ, 100);
 	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_OPEN,
-				"Object Open");
-	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_RP,
-				"Object RP");
+				"Object Open", "objectOpen");
+	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_RP, "Object RP",
+				"objectRP");
 	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_NOPATH,
-				"Object Nopath");
-	create_subgroup_counter(
-		rx_obj_subgroup,
-		((PCEP_OBJ_CLASS_ENDPOINTS << 4) | PCEP_OBJ_TYPE_ENDPOINT_IPV4),
-		"Object Endpoint IPv4");
-	create_subgroup_counter(
-		rx_obj_subgroup,
-		((PCEP_OBJ_CLASS_ENDPOINTS << 4) | PCEP_OBJ_TYPE_ENDPOINT_IPV6),
-		"Object Endpoint IPv6");
+				"Object Nopath", "objectNopath");
+	create_subgroup_counter(rx_obj_subgroup,
+				((PCEP_OBJ_CLASS_ENDPOINTS << 4) |
+				 PCEP_OBJ_TYPE_ENDPOINT_IPV4),
+				"Object Endpoint IPv4", "objectEndpointIPv4");
+	create_subgroup_counter(rx_obj_subgroup,
+				((PCEP_OBJ_CLASS_ENDPOINTS << 4) |
+				 PCEP_OBJ_TYPE_ENDPOINT_IPV6),
+				"Object Endpoint IPv6", "objectEndpointIPv6");
 	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_BANDWIDTH,
-				"Object Bandwidth");
+				"Object Bandwidth", "objectBandwidth");
 	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_METRIC,
-				"Object Metric");
+				"Object Metric", "objectMetric");
 	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_ERO,
-				"Object ERO");
+				"Object ERO", "objectERO");
 	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_RRO,
-				"Object RRO");
+				"Object RRO", "objectRRO");
 	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_LSPA,
-				"Object LSPA");
+				"Object LSPA", "objectLSPA");
 	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_IRO,
-				"Object IRO");
+				"Object IRO", "objectIRO");
 	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_SVEC,
-				"Object SVEC");
+				"Object SVEC", "objectSVEC");
 	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_NOTF,
-				"Object Notify");
+				"Object Notify", "objectNotify");
 	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_ERROR,
-				"Object Error");
+				"Object Error", "objectError");
 	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_CLOSE,
-				"Object Close");
+				"Object Close", "objectClose");
 	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_LSP,
-				"Object LSP");
+				"Object LSP", "objectLSP");
 	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_SRP,
-				"Object SRP");
+				"Object SRP", "objectSRP");
 	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_VENDOR_INFO,
-				"Object Vendor Info");
+				"Object Vendor Info", "objectVendorInfo");
 	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_INTER_LAYER,
-				"Object Inter-Layer");
+				"Object Inter-Layer", "objectInterLayer");
 	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_SWITCH_LAYER,
-				"Object Switch-Layer");
+				"Object Switch-Layer", "objectSwitchLayer");
 	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_REQ_ADAP_CAP,
-				"Object Requested Adap-Cap");
+				"Object Requested Adap-Cap",
+				"objectRequestedAdapCap");
 	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_SERVER_IND,
-				"Object Server-Indication");
+				"Object Server-Indication",
+				"objectServerIndication");
 	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_ASSOCIATION,
-				"Object Association");
+				"Object Association", "objectAssociation");
 	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_MAX,
-				"Object Unknown");
+				"Object Unknown", "objectUnknown");
 	create_subgroup_counter(rx_obj_subgroup, PCEP_OBJ_CLASS_MAX + 1,
-				"Object Erroneous");
+				"Object Erroneous", "objectErroneous");
 
 	struct counters_subgroup *tx_obj_subgroup =
 		clone_counters_subgroup(rx_obj_subgroup, "TX Object counters",
@@ -151,21 +141,22 @@ void create_session_counters(pcep_session *session)
 		"RX RO Sub-Object counters", COUNTER_SUBGROUP_ID_RX_SUBOBJ,
 		RO_SUBOBJ_UNKNOWN + 2);
 	create_subgroup_counter(rx_subobj_subgroup, RO_SUBOBJ_TYPE_IPV4,
-				"RO Sub-Object IPv4");
+				"RO Sub-Object IPv4", "ROSubObjectIPv4");
 	create_subgroup_counter(rx_subobj_subgroup, RO_SUBOBJ_TYPE_IPV6,
-				"RO Sub-Object IPv6");
+				"RO Sub-Object IPv6", "ROSubObjectIPv6");
 	create_subgroup_counter(rx_subobj_subgroup, RO_SUBOBJ_TYPE_LABEL,
-				"RO Sub-Object Label");
+				"RO Sub-Object Label", "ROSubObjectLabel");
 	create_subgroup_counter(rx_subobj_subgroup, RO_SUBOBJ_TYPE_UNNUM,
-				"RO Sub-Object Unnum");
+				"RO Sub-Object Unnum", "ROSubObjectUnnum");
 	create_subgroup_counter(rx_subobj_subgroup, RO_SUBOBJ_TYPE_ASN,
-				"RO Sub-Object ASN");
+				"RO Sub-Object ASN", "ROSubObjectASN");
 	create_subgroup_counter(rx_subobj_subgroup, RO_SUBOBJ_TYPE_SR,
-				"RO Sub-Object SR");
+				"RO Sub-Object SR", "ROSubObjectSR");
 	create_subgroup_counter(rx_subobj_subgroup, RO_SUBOBJ_UNKNOWN,
-				"RO Sub-Object Unknown");
+				"RO Sub-Object Unknown", "ROSubObjectUnknown");
 	create_subgroup_counter(rx_subobj_subgroup, RO_SUBOBJ_UNKNOWN + 1,
-				"RO Sub-Object Erroneous");
+				"RO Sub-Object Erroneous",
+				"ROSubObjectErroneous");
 
 	struct counters_subgroup *tx_subobj_subgroup = clone_counters_subgroup(
 		rx_subobj_subgroup, "TX RO Sub-Object counters",
@@ -180,28 +171,36 @@ void create_session_counters(pcep_session *session)
 					 PCEP_SR_SUBOBJ_NAI_UNKNOWN + 1);
 	create_subgroup_counter(rx_subobj_sr_nai_subgroup,
 				PCEP_SR_SUBOBJ_NAI_ABSENT,
-				"RO Sub-Object SR NAI absent");
+				"RO Sub-Object SR NAI absent",
+				"ROSubObjectSRNAIAbsent");
 	create_subgroup_counter(rx_subobj_sr_nai_subgroup,
 				PCEP_SR_SUBOBJ_NAI_IPV4_NODE,
-				"RO Sub-Object SR NAI IPv4 Node");
+				"RO Sub-Object SR NAI IPv4 Node",
+				"ROSubObjectSRNAIIPv4Node");
 	create_subgroup_counter(rx_subobj_sr_nai_subgroup,
 				PCEP_SR_SUBOBJ_NAI_IPV6_NODE,
-				"RO Sub-Object SR NAI IPv6 Node");
+				"RO Sub-Object SR NAI IPv6 Node",
+				"ROSubObjectSRNAIIPv6Node");
 	create_subgroup_counter(rx_subobj_sr_nai_subgroup,
 				PCEP_SR_SUBOBJ_NAI_IPV4_ADJACENCY,
-				"RO Sub-Object SR NAI IPv4 Adj");
+				"RO Sub-Object SR NAI IPv4 Adj",
+				"ROSubObjectSRNAIIPv4Adj");
 	create_subgroup_counter(rx_subobj_sr_nai_subgroup,
 				PCEP_SR_SUBOBJ_NAI_IPV6_ADJACENCY,
-				"RO Sub-Object SR NAI IPv6 Adj");
+				"RO Sub-Object SR NAI IPv6 Adj",
+				"ROSubObjectSRNAIIPv6Adj");
 	create_subgroup_counter(rx_subobj_sr_nai_subgroup,
 				PCEP_SR_SUBOBJ_NAI_UNNUMBERED_IPV4_ADJACENCY,
-				"RO Sub-Object SR NAI Unnumbered IPv4 Adj");
+				"RO Sub-Object SR NAI Unnumbered IPv4 Adj",
+				"ROSubObjectSRNAIUnnumberedIPv4Adj");
 	create_subgroup_counter(rx_subobj_sr_nai_subgroup,
 				PCEP_SR_SUBOBJ_NAI_LINK_LOCAL_IPV6_ADJACENCY,
-				"RO Sub-Object SR NAI Link Local IPv6 Adj");
+				"RO Sub-Object SR NAI Link Local IPv6 Adj",
+				"ROSubObjectSRNAILinkLocalIPv6Adj");
 	create_subgroup_counter(rx_subobj_sr_nai_subgroup,
 				PCEP_SR_SUBOBJ_NAI_UNKNOWN,
-				"RO Sub-Object SR NAI Unknown");
+				"RO Sub-Object SR NAI Unknown",
+				"ROSubObjectSRNAIUnknown");
 
 	struct counters_subgroup *tx_subobj_sr_nai_subgroup =
 		clone_counters_subgroup(rx_subobj_sr_nai_subgroup,
@@ -216,56 +215,60 @@ void create_session_counters(pcep_session *session)
 		PCEP_OBJ_TLV_TYPE_UNKNOWN + 1);
 	create_subgroup_counter(rx_tlv_subgroup,
 				PCEP_OBJ_TLV_TYPE_NO_PATH_VECTOR,
-				"TLV No Path Vector");
+				"TLV No Path Vector", "TLVNoPathVector");
 	create_subgroup_counter(rx_tlv_subgroup, PCEP_OBJ_TLV_TYPE_VENDOR_INFO,
-				"TLV Vendor Info");
+				"TLV Vendor Info", "TLVVendorInfo");
 	create_subgroup_counter(rx_tlv_subgroup,
 				PCEP_OBJ_TLV_TYPE_STATEFUL_PCE_CAPABILITY,
-				"TLV Stateful PCE Capability");
+				"TLV Stateful PCE Capability",
+				"TLVStatefulPCCapability");
 	create_subgroup_counter(rx_tlv_subgroup,
 				PCEP_OBJ_TLV_TYPE_SYMBOLIC_PATH_NAME,
-				"TLV Symbolic Path Name");
+				"TLV Symbolic Path Name", "TLVSymbolicPathName");
 	create_subgroup_counter(rx_tlv_subgroup,
 				PCEP_OBJ_TLV_TYPE_IPV4_LSP_IDENTIFIERS,
-				"TLV IPv4 LSP Identifier");
+				"TLV IPv4 LSP Identifier",
+				"TLVIPv4LSPIdentifier");
 	create_subgroup_counter(rx_tlv_subgroup,
 				PCEP_OBJ_TLV_TYPE_IPV6_LSP_IDENTIFIERS,
-				"TLV IPv6 LSP Identifier");
+				"TLV IPv6 LSP Identifier",
+				"TLVIPv6LSPIdentifier");
 	create_subgroup_counter(rx_tlv_subgroup,
 				PCEP_OBJ_TLV_TYPE_LSP_ERROR_CODE,
-				"TLV LSP Error Code");
+				"TLV LSP Error Code", "TLVLSPErrorCode");
 	create_subgroup_counter(rx_tlv_subgroup,
 				PCEP_OBJ_TLV_TYPE_RSVP_ERROR_SPEC,
-				"TLV RSVP Error Spec");
+				"TLV RSVP Error Spec", "TLVRSVPErrorSpec");
 	create_subgroup_counter(rx_tlv_subgroup,
 				PCEP_OBJ_TLV_TYPE_LSP_DB_VERSION,
-				"TLV LSP DB Version");
+				"TLV LSP DB Version", "TLVLSPDBVersion");
 	create_subgroup_counter(rx_tlv_subgroup,
 				PCEP_OBJ_TLV_TYPE_SPEAKER_ENTITY_ID,
-				"TLV Speaker Entity ID");
+				"TLV Speaker Entity ID", "TLVSpeakerEntityId");
 	create_subgroup_counter(rx_tlv_subgroup,
 				PCEP_OBJ_TLV_TYPE_SR_PCE_CAPABILITY,
-				"TLV SR PCE Capability");
+				"TLV SR PCE Capability", "TLVSRPCECapability");
 	create_subgroup_counter(rx_tlv_subgroup,
 				PCEP_OBJ_TLV_TYPE_PATH_SETUP_TYPE,
-				"TLV Path Setup Type");
+				"TLV Path Setup Type", "TLVPathSetupType");
 	create_subgroup_counter(rx_tlv_subgroup,
 				PCEP_OBJ_TLV_TYPE_PATH_SETUP_TYPE_CAPABILITY,
-				"TLV Path Setup Type Capability");
+				"TLV Path Setup Type Capability",
+				"TLVPathSetupTypeCapability");
 	create_subgroup_counter(rx_tlv_subgroup,
 				PCEP_OBJ_TLV_TYPE_SRPOLICY_POL_ID,
-				"TLV SR Policy PolId");
+				"TLV SR Policy PolId", "TLVSRPolicyPolId");
 	create_subgroup_counter(rx_tlv_subgroup,
 				PCEP_OBJ_TLV_TYPE_SRPOLICY_POL_NAME,
-				"TLV SR Policy PolName");
+				"TLV SR Policy PolName", "TLVSRPolicyPolName");
 	create_subgroup_counter(rx_tlv_subgroup,
 				PCEP_OBJ_TLV_TYPE_SRPOLICY_CPATH_ID,
-				"TLV SR Policy CpathId");
+				"TLV SR Policy CpathId", "TLVSRPolicyCpathId");
 	create_subgroup_counter(rx_tlv_subgroup,
 				PCEP_OBJ_TLV_TYPE_SRPOLICY_CPATH_PREFERENCE,
-				"TLV SR Policy CpathRef");
+				"TLV SR Policy CpathRef", "TLVSRPolicyCpathRef");
 	create_subgroup_counter(rx_tlv_subgroup, PCEP_OBJ_TLV_TYPE_UNKNOWN,
-				"TLV Unknown");
+				"TLV Unknown", "TLVUnknown");
 
 	struct counters_subgroup *tx_tlv_subgroup = clone_counters_subgroup(
 		rx_tlv_subgroup, "TX TLV counters", COUNTER_SUBGROUP_ID_TX_TLV);
@@ -277,28 +280,32 @@ void create_session_counters(pcep_session *session)
 		"Events counters", COUNTER_SUBGROUP_ID_EVENT, MAX_COUNTERS);
 	create_subgroup_counter(events_subgroup,
 				PCEP_EVENT_COUNTER_ID_PCC_CONNECT,
-				"PCC connect");
+				"PCC connect", "PCCConnect");
 	create_subgroup_counter(events_subgroup,
 				PCEP_EVENT_COUNTER_ID_PCE_CONNECT,
-				"PCE connect");
+				"PCE connect", "PCEConnect");
 	create_subgroup_counter(events_subgroup,
 				PCEP_EVENT_COUNTER_ID_PCC_DISCONNECT,
-				"PCC disconnect");
+				"PCC disconnect", "PCCDisconnect");
 	create_subgroup_counter(events_subgroup,
 				PCEP_EVENT_COUNTER_ID_PCE_DISCONNECT,
-				"PCE disconnect");
+				"PCE disconnect", "PCEDisconnect");
 	create_subgroup_counter(events_subgroup,
 				PCEP_EVENT_COUNTER_ID_TIMER_KEEPALIVE,
-				"Timer KeepAlive expired");
+				"Timer KeepAlive expired",
+				"timerKeepAliveExpired");
 	create_subgroup_counter(events_subgroup,
 				PCEP_EVENT_COUNTER_ID_TIMER_DEADTIMER,
-				"Timer DeadTimer expired");
+				"Timer DeadTimer expired",
+				"timerDeadTimerExpired");
 	create_subgroup_counter(events_subgroup,
 				PCEP_EVENT_COUNTER_ID_TIMER_OPENKEEPWAIT,
-				"Timer OpenKeepWait expired");
+				"Timer OpenKeepWait expired",
+				"timerOpenKeepWaitExpired");
 	create_subgroup_counter(events_subgroup,
 				PCEP_EVENT_COUNTER_ID_TIMER_OPENKEEPALIVE,
-				"Timer OpenKeepAlive expired");
+				"Timer OpenKeepAlive expired",
+				"timerOpenKeepAliveExpired");
 
 	/*
 	 * Create the parent counters group
