@@ -183,6 +183,8 @@ struct pim_interface *pim_if_new(struct interface *ifp, bool gm, bool pim,
 	pim_if_add_vif(ifp, ispimreg, is_vxlan_term);
 	pim_ifp->pim->mcast_if_count++;
 
+	pim_filter_ref_init(&pim_ifp->gmp_filter);
+
 	return pim_ifp;
 }
 
@@ -221,6 +223,8 @@ void pim_if_delete(struct interface *ifp)
 
 	pim_igmp_if_fini(pim_ifp);
 
+	pim_filter_ref_fini(&pim_ifp->gmp_filter);
+
 	list_delete(&pim_ifp->pim_neighbor_list);
 	list_delete(&pim_ifp->upstream_switch_list);
 	list_delete(&pim_ifp->sec_addr_list);
@@ -1202,7 +1206,7 @@ long pim_if_t_suppressed_msec(struct interface *ifp)
 
 	/* t_suppressed = t_periodic * rand(1.1, 1.4) */
 	ramount = 1100 + (frr_weak_random() % (1400 - 1100 + 1));
-	t_suppressed_msec = router->t_periodic * ramount;
+	t_suppressed_msec = (long)(router->t_periodic) * ramount;
 
 	return t_suppressed_msec;
 }
