@@ -824,7 +824,7 @@ int pim_igmp_packet(struct gm_sock *igmp, char *buf, size_t len)
 					   igmp_msg, igmp_msg_len);
 
 	case PIM_IGMP_V2_MEMBERSHIP_REPORT:
-		return igmp_v2_recv_report(igmp, ip_hdr->ip_src, from_str,
+		return igmp_v2_recv_report(igmp, ip_hdr->ip_src, ip_hdr->ip_dst, from_str,
 					   igmp_msg, igmp_msg_len);
 
 	case PIM_IGMP_V1_MEMBERSHIP_REPORT:
@@ -1396,6 +1396,22 @@ static void group_timer_off(struct gm_group *group)
 void igmp_group_timer_on(struct gm_group *group, long interval_msec,
 			 const char *ifname)
 {
+	struct pim_interface *pim_ifp = group->interface->info;
+	struct prefix_sg sg = {
+		.family = AF_INET,
+		.prefixlen = IPV4_MAX_BITLEN,
+		.grp.ipa_type = IPADDR_V4,
+		.grp.ipaddr_v4 = group->group_addr,
+	};
+
+	if (interval_msec && !pim_filter_match(&pim_ifp->gmp_filter, &sg, group->interface)) {
+		if (PIM_DEBUG_GM_TRACE)
+			zlog_debug("Timer for %pPSG on %s not refreshed due to route-map reject",
+				   &sg, ifname);
+
+		return;
+	}
+
 	group_timer_off(group);
 
 	if (PIM_DEBUG_GM_EVENTS) {
