@@ -30,6 +30,7 @@
 #include "pim_jp_agg.h"
 #include "pim_util.h"
 #include "pim_ssm.h"
+#include "pim_dm.h"
 
 static void on_trace(const char *label, struct interface *ifp, pim_addr src)
 {
@@ -112,6 +113,11 @@ static void recv_join(struct interface *ifp, struct pim_neighbor *neigh,
 
 		sg->src = PIMADDR_ANY;
 	}
+	if (pim_iface_grp_dm(pim_ifp, sg->grp)) {
+		zlog_warn("%s: Specified Group(%pPA) in join is now in DM, not allowed to create PIM state",
+			  __func__, &sg->grp);
+		return;
+	}
 
 	/* Restart join expiry timer */
 	pim_ifchannel_join_add(ifp, neigh->source_addr, upstream, sg,
@@ -136,6 +142,9 @@ static void recv_prune(struct interface *ifp, struct pim_neighbor *neigh,
 
 	++pim_ifp->pim_ifstat_prune_recv;
 
+
+	pim_dm_recv_prune(ifp, neigh, holdtime, upstream, sg, source_flags);
+
 	if (CHECK_FLAG(source_flags, PIM_WILDCARD_BIT_MASK)) {
 		/* As per RFC 7761 Section 4.9.1:
 		 * The RPT (or Rendezvous Point Tree) bit is a 1-bit value for
@@ -274,6 +283,12 @@ int pim_joinprune_recv(struct interface *ifp, struct pim_neighbor *neigh,
 				msg_num_joined_sources, msg_num_pruned_sources,
 				&src_addr, ifp->name);
 
+		remain = (pastend - buf) / sizeof(pim_encoded_source);
+		if (msg_num_joined_sources > remain) {
+			zlog_warn("%s: short join buffer for source list: size=%d minimum=%d from %pPA on %s",
+				  __func__, remain, msg_num_joined_sources, &src_addr, ifp->name);
+			return -6;
+		}
 		/* boundary check */
 		group_filtered = pim_is_group_filtered(pim_ifp, &sg.grp, NULL);
 
@@ -302,6 +317,13 @@ int pim_joinprune_recv(struct interface *ifp, struct pim_neighbor *neigh,
 			}
 		}
 
+		remain = (pastend - buf) / sizeof(pim_encoded_source);
+		if (msg_num_pruned_sources > remain) {
+			zlog_warn("%s: short prune buffer for source list: size=%d minimum=%d from %pPA on %s",
+				  __func__, remain, msg_num_pruned_sources, &src_addr, ifp->name);
+			return -6;
+		}
+
 		/* Scan pruned sources */
 		for (source = 0; source < msg_num_pruned_sources; ++source) {
 			addr_offset = pim_parse_addr_source(
@@ -331,9 +353,9 @@ int pim_joinprune_recv(struct interface *ifp, struct pim_neighbor *neigh,
 				if (PIM_IF_FLAG_TEST_S_G_RPT(child->flags)) {
 					if (child->ifjoin_state
 					    == PIM_IFJOIN_PRUNE_PENDING_TMP)
-						EVENT_OFF(
+						event_cancel(&
 							child->t_ifjoin_prune_pending_timer);
-					EVENT_OFF(child->t_ifjoin_expiry_timer);
+					event_cancel(&child->t_ifjoin_expiry_timer);
 					PIM_IF_FLAG_UNSET_S_G_RPT(child->flags);
 					child->ifjoin_state = PIM_IFJOIN_NOINFO;
 					delete_on_noinfo(child);
@@ -365,6 +387,161 @@ int pim_joinprune_recv(struct interface *ifp, struct pim_neighbor *neigh,
 	return 0;
 }
 
+
+int pim_graft_recv(struct interface *ifp, struct pim_neighbor *neigh, pim_addr src_addr,
+		   uint8_t *tlv_buf, int tlv_buf_size, uint8_t pim_msg_type)
+{
+	pim_addr msg_upstream_addr;
+	bool wrong_af = false;
+	struct pim_interface *pim_ifp;
+	uint8_t msg_num_groups;
+	uint16_t msg_holdtime;
+	int addr_offset;
+	uint8_t *buf;
+	uint8_t *pastend;
+	int remain;
+	int group;
+	struct pim_upstream *up;
+
+	buf = tlv_buf;
+	pastend = tlv_buf + tlv_buf_size;
+	pim_ifp = ifp->info;
+
+	if (pim_ifp->pim_passive_enable) {
+		if (PIM_DEBUG_PIM_PACKETS)
+			zlog_debug("skip receiving PIM message on passive interface %s", ifp->name);
+		return 0;
+	}
+
+	/*
+	 * Parse ucast addr
+	 */
+	addr_offset = pim_parse_addr_ucast(&msg_upstream_addr, buf, pastend - buf, &wrong_af);
+	if (addr_offset < 1) {
+		zlog_warn("%s: pim_parse_addr_ucast() failure: from %pPA on %s", __func__,
+			  &src_addr, ifp->name);
+		return -1;
+	}
+	buf += addr_offset;
+
+	/*
+	 * Check upstream address family
+	 */
+	if (wrong_af) {
+		zlog_warn("%s: ignoring join/prune directed to unexpected addr family from %pPA on %s",
+			  __func__, &src_addr, ifp->name);
+		return -2;
+	}
+
+	remain = pastend - buf;
+	if (remain < 4) {
+		zlog_warn("%s: short join/prune message buffer for group list: size=%d minimum=%d from %pPA on %s",
+			  __func__, remain, 4, &src_addr, ifp->name);
+		return -4;
+	}
+
+	++buf; /* skip reserved byte */
+	msg_num_groups = *(const uint8_t *)buf;
+	++buf;
+	msg_holdtime = ntohs(*(const uint16_t *)buf);
+	++buf;
+	++buf;
+
+	if (PIM_DEBUG_GRAFT)
+		zlog_debug("%s: graft upstream=%pPAs groups=%d holdtime=%d from %pPA on %s",
+			   __func__, &msg_upstream_addr, msg_num_groups, msg_holdtime, &src_addr,
+			   ifp->name);
+
+	/* Scan groups */
+	for (group = 0; group < msg_num_groups; ++group) {
+		pim_sgaddr sg;
+		uint8_t msg_source_flags;
+		uint16_t msg_num_joined_sources;
+		uint16_t msg_num_pruned_sources;
+		int source;
+		bool group_filtered = false;
+
+		memset(&sg, 0, sizeof(sg));
+		addr_offset = pim_parse_addr_group(&sg, buf, pastend - buf);
+		if (addr_offset < 1)
+			return -5;
+
+		buf += addr_offset;
+
+		remain = pastend - buf;
+		if (remain < 4) {
+			zlog_warn("%s: short graft buffer for source list: size=%d minimum=%d from %pPA on %s",
+				  __func__, remain, 4, &src_addr, ifp->name);
+			return -6;
+		}
+
+		msg_num_joined_sources = ntohs(*(const uint16_t *)buf);
+		buf += 2;
+		msg_num_pruned_sources = ntohs(*(const uint16_t *)buf);
+		buf += 2;
+
+		if (PIM_DEBUG_GRAFT)
+			zlog_debug("%s: graft upstream=%pPAs group=%pPA/32 join_src=%d prune_src=%d from %pPA on %s",
+				   __func__, &msg_upstream_addr, &sg.grp, msg_num_joined_sources,
+				   msg_num_pruned_sources, &src_addr, ifp->name);
+
+		remain = (pastend - buf) / sizeof(pim_encoded_source);
+		if (msg_num_joined_sources > remain) {
+			zlog_warn("%s: short graft join buffer for source list: remaining=%d minimum=%d from %pPA on %s",
+				  __func__, remain, msg_num_joined_sources, &src_addr, ifp->name);
+			return -6;
+		}
+
+		/* sanity and boundary check */
+		group_filtered = !pim_addr_is_multicast(sg.grp) ||
+				 pim_is_group_filtered(pim_ifp, &sg.grp, &sg.src);
+
+		/* Scan joined sources */
+		for (source = 0; source < msg_num_joined_sources; ++source) {
+			addr_offset = pim_parse_addr_source(&sg, &msg_source_flags, buf,
+							    pastend - buf);
+			if (addr_offset < 1)
+				return -7;
+
+			buf += addr_offset;
+
+			/* if we are filtering this group or (S,G), skip the graft */
+			if (group_filtered || pim_is_group_filtered(pim_ifp, &sg.grp, &sg.src))
+				continue;
+
+			if (pim_msg_type == PIM_MSG_TYPE_GRAFT)
+				pim_dm_recv_graft(ifp, &sg);
+			else if (pim_msg_type == PIM_MSG_TYPE_GRAFT_ACK) {
+				up = pim_upstream_find(pim_ifp->pim, &sg);
+				if (up)
+					event_cancel(&up->t_graft_timer);
+			}
+		}
+
+		/* Graft msg shouldn't have prune, but just in case, skip and log */
+		if (msg_num_pruned_sources) {
+			remain = (pastend - buf) / sizeof(pim_encoded_source);
+			if (msg_num_pruned_sources > remain) {
+				zlog_warn("%s: short graft prune buffer for source list: remaining=%d minimum=%d from %pPA on %s",
+					  __func__, remain, msg_num_pruned_sources, &src_addr,
+					  ifp->name);
+				return -6;
+			}
+
+			if (PIM_DEBUG_GRAFT)
+				zlog_debug("%s: ignore prune in graft msg, upstream=%pPAs group=%pPA/32 join_src=%d prune_src=%d from %pPA on %s",
+					   __func__, &msg_upstream_addr, &sg.grp,
+					   msg_num_joined_sources, msg_num_pruned_sources,
+					   &src_addr, ifp->name);
+
+			buf += msg_num_pruned_sources * sizeof(pim_encoded_source);
+		}
+
+	} /* scan groups */
+
+	return 0;
+}
+
 /*
  * J/P Message Format
  *
@@ -607,3 +784,155 @@ int pim_joinprune_send(struct pim_rpf *rpf, struct list *groups)
 	}
 	return 0;
 }
+
+int pim_graft_send(struct pim_rpf *rpf, struct list *groups)
+{
+	struct pim_jp_agg_group *group;
+	struct pim_interface *pim_ifp = NULL;
+	struct pim_jp_groups *grp = NULL;
+	struct pim_jp *msg = NULL;
+	struct listnode *node, *nnode;
+	uint8_t pim_msg[10000];
+	uint8_t *curr_ptr = pim_msg;
+	bool new_packet = true;
+	size_t packet_left = 0;
+	size_t packet_size = 0;
+	size_t group_size = 0;
+
+	if (rpf->source_nexthop.interface)
+		pim_ifp = rpf->source_nexthop.interface->info;
+	else {
+		zlog_warn("%s: RPF interface is not present", __func__);
+		return -1;
+	}
+
+	on_trace(__func__, rpf->source_nexthop.interface, rpf->rpf_addr);
+
+	if (!pim_ifp) {
+		zlog_warn("%s: multicast not enabled on interface %s", __func__,
+			  rpf->source_nexthop.interface->name);
+		return -1;
+	}
+
+	if (pim_addr_is_any(rpf->rpf_addr)) {
+		if (PIM_DEBUG_PIM_J_P)
+			zlog_debug("%s: upstream=%pPA is myself on interface %s", __func__,
+				   &rpf->rpf_addr, rpf->source_nexthop.interface->name);
+		return 0;
+	}
+
+	/*
+	  RFC 4601: 4.3.1.  Sending Hello Messages
+
+	  Thus, if a router needs to send a Join/Prune or Assert message on
+	  an interface on which it has not yet sent a Hello message with the
+	  currently configured IP address, then it MUST immediately send the
+	  relevant Hello message without waiting for the Hello Timer to
+	  expire, followed by the Join/Prune or Assert message.
+	*/
+	pim_hello_require(rpf->source_nexthop.interface);
+
+	for (ALL_LIST_ELEMENTS(groups, node, nnode, group)) {
+		if (new_packet) {
+			msg = (struct pim_jp *)pim_msg;
+
+			memset(msg, 0, sizeof(*msg));
+
+			pim_msg_addr_encode_ucast((uint8_t *)&msg->addr, rpf->rpf_addr);
+			msg->reserved = 0;
+			msg->holdtime = 0; // htons(PIM_JP_HOLDTIME);
+
+			new_packet = false;
+
+			grp = &msg->groups[0];
+			curr_ptr = (uint8_t *)grp;
+			packet_size = sizeof(struct pim_msg_header);
+			packet_size += sizeof(pim_encoded_unicast);
+			packet_size += 4; // reserved (1) + groups (1) + holdtime (2)
+
+			packet_left = rpf->source_nexthop.interface->mtu - 24;
+			packet_left -= packet_size;
+		}
+		if (PIM_DEBUG_PIM_J_P)
+			zlog_debug("%s: sending (G)=%pPAs to upstream=%pPA on interface %s",
+				   __func__, &group->group, &rpf->rpf_addr,
+				   rpf->source_nexthop.interface->name);
+
+		group_size = pim_msg_get_jp_group_size(group->sources);
+		if (group_size > packet_left) {
+			pim_msg_build_header(pim_ifp->primary_address, qpim_all_pim_routers_addr,
+					     pim_msg, packet_size, PIM_MSG_TYPE_GRAFT, false);
+			if (pim_msg_send(pim_ifp->pim_sock_fd, pim_ifp->primary_address,
+					 qpim_all_pim_routers_addr, pim_msg, packet_size,
+					 rpf->source_nexthop.interface)) {
+				zlog_warn("%s: could not send PIM message on interface %s",
+					  __func__, rpf->source_nexthop.interface->name);
+			}
+
+			msg = (struct pim_jp *)pim_msg;
+			memset(msg, 0, sizeof(*msg));
+
+			pim_msg_addr_encode_ucast((uint8_t *)&msg->addr, rpf->rpf_addr);
+			msg->reserved = 0;
+			msg->holdtime = 0; // htons(PIM_JP_HOLDTIME);
+
+			new_packet = false;
+
+			grp = &msg->groups[0];
+			curr_ptr = (uint8_t *)grp;
+			packet_size = sizeof(struct pim_msg_header);
+			packet_size += sizeof(pim_encoded_unicast);
+			packet_size += 4; // reserved (1) + groups (1) + holdtime (2)
+
+			packet_left = rpf->source_nexthop.interface->mtu - 24;
+			packet_left -= packet_size;
+		}
+
+		msg->num_groups++;
+		/*
+		  Build PIM message
+		*/
+
+		curr_ptr += group_size;
+		packet_left -= group_size;
+		packet_size += group_size;
+		pim_msg_build_jp_groups(grp, group, group_size);
+
+		if (!pim_ifp->pim_passive_enable) {
+			pim_ifp->pim_ifstat_join_send += ntohs(grp->joins);
+			pim_ifp->pim_ifstat_prune_send += ntohs(grp->prunes);
+		}
+
+		if (PIM_DEBUG_PIM_TRACE)
+			zlog_debug("%s: interface %s num_joins %u num_prunes %u", __func__,
+				   rpf->source_nexthop.interface->name, ntohs(grp->joins),
+				   ntohs(grp->prunes));
+
+		grp = (struct pim_jp_groups *)curr_ptr;
+		if (packet_left < sizeof(struct pim_jp_groups) || msg->num_groups == 255) {
+			pim_msg_build_header(pim_ifp->primary_address, qpim_all_pim_routers_addr,
+					     pim_msg, packet_size, PIM_MSG_TYPE_GRAFT, false);
+			if (pim_msg_send(pim_ifp->pim_sock_fd, pim_ifp->primary_address,
+					 qpim_all_pim_routers_addr, pim_msg, packet_size,
+					 rpf->source_nexthop.interface)) {
+				zlog_warn("%s: could not send PIM message on interface %s",
+					  __func__, rpf->source_nexthop.interface->name);
+			}
+
+			new_packet = true;
+		}
+	}
+
+	if (!new_packet) {
+		// msg->num_groups = htons (msg->num_groups);
+		pim_msg_build_header(pim_ifp->primary_address, qpim_all_pim_routers_addr, pim_msg,
+				     packet_size, PIM_MSG_TYPE_GRAFT, false);
+		if (pim_msg_send(pim_ifp->pim_sock_fd, pim_ifp->primary_address,
+				 qpim_all_pim_routers_addr, pim_msg, packet_size,
+				 rpf->source_nexthop.interface)) {
+			zlog_warn("%s: could not send PIM message on interface %s", __func__,
+				  rpf->source_nexthop.interface->name);
+		}
+	}
+	return 0;
+}
