@@ -28,6 +28,7 @@
 #include "pim_register.h"
 #include "pim_errors.h"
 #include "pim_bsm.h"
+#include "pim_state_refresh.h"
 #include <lib/lib_errors.h>
 
 static void on_pim_hello_send(struct event *t);
@@ -53,6 +54,8 @@ static const char *pim_pim_msgtype2str(enum pim_msg_type type)
 		return "GACK";
 	case PIM_MSG_TYPE_CANDIDATE:
 		return "CANDIDATE";
+	case PIM_MSG_TYPE_STATE_REFRESH:
+		return "STATE_REFRESH";
 	}
 
 	return "UNKNOWN";
@@ -69,7 +72,7 @@ static void sock_close(struct interface *ifp)
 				pim_ifp->pim_sock_fd, ifp->name);
 		}
 	}
-	EVENT_OFF(pim_ifp->t_pim_sock_read);
+	event_cancel(&pim_ifp->t_pim_sock_read);
 
 	if (PIM_DEBUG_PIM_TRACE) {
 		if (pim_ifp->t_pim_hello_timer) {
@@ -78,7 +81,7 @@ static void sock_close(struct interface *ifp)
 				ifp->name);
 		}
 	}
-	EVENT_OFF(pim_ifp->t_pim_hello_timer);
+	event_cancel(&pim_ifp->t_pim_hello_timer);
 
 	if (PIM_DEBUG_PIM_TRACE) {
 		zlog_debug("Deleting PIM socket fd=%d on interface %s",
@@ -149,9 +152,13 @@ int pim_pim_packet(struct interface *ifp, uint8_t *buf, size_t len,
 	uint32_t pim_msg_len = 0;
 	uint16_t pim_checksum; /* received checksum */
 	uint16_t checksum;     /* computed checksum */
-	struct pim_neighbor *neigh;
+	struct pim_interface *pim_ifp = ifp->info;
+	struct prefix src_prefix;
+	struct prefix_list *nbr_plist = NULL;
+	struct pim_neighbor *neigh = NULL;
 	struct pim_msg_header *header;
 	bool   no_fwd;
+	uint32_t rv;
 
 #if PIM_IPV == 4
 	if (len <= sizeof(*ip_hdr)) {
@@ -205,6 +212,41 @@ int pim_pim_packet(struct interface *ifp, uint8_t *buf, size_t len,
 		return -1;
 	}
 
+	switch (header->type) {
+	case PIM_MSG_TYPE_HELLO:
+	case PIM_MSG_TYPE_JOIN_PRUNE:
+	case PIM_MSG_TYPE_ASSERT:
+		if (pim_ifp == NULL || pim_ifp->nbr_plist == NULL)
+			break;
+
+		nbr_plist = prefix_list_lookup(PIM_AFI, pim_ifp->nbr_plist);
+
+#if PIM_IPV == 4
+		src_prefix.family = AF_INET;
+		src_prefix.prefixlen = IPV4_MAX_BITLEN;
+		src_prefix.u.prefix4 = sg.src;
+#else
+		src_prefix.family = AF_INET6;
+		src_prefix.prefixlen = IPV6_MAX_BITLEN;
+		src_prefix.u.prefix6 = sg.src;
+#endif
+
+		if (nbr_plist &&
+		    prefix_list_apply_ext(nbr_plist, NULL, &src_prefix, true) == PREFIX_PERMIT)
+			break;
+
+#if PIM_IPV == 4
+		if (PIM_DEBUG_PIM_PACKETS)
+			zlog_debug("neighbor filter rejects packet %pI4 -> %pI4 on %s",
+				   &ip_hdr->ip_src, &ip_hdr->ip_dst, ifp->name);
+#else
+		if (PIM_DEBUG_PIM_PACKETS)
+			zlog_debug("neighbor filter rejects packet %pI6 -> %pI6 on %s", &sg.src,
+				   &sg.grp, ifp->name);
+#endif
+		return -1;
+	}
+
 	/* save received checksum */
 	pim_checksum = header->checksum;
 
@@ -303,6 +345,36 @@ int pim_pim_packet(struct interface *ifp, uint8_t *buf, size_t len,
 		return pim_register_stop_recv(ifp, pim_msg + PIM_MSG_HEADER_LEN,
 					      pim_msg_len - PIM_MSG_HEADER_LEN);
 		break;
+	case PIM_MSG_TYPE_GRAFT_ACK:
+		return pim_graft_recv(ifp, neigh, sg.src, pim_msg + PIM_MSG_HEADER_LEN,
+				      pim_msg_len - PIM_MSG_HEADER_LEN, PIM_MSG_TYPE_GRAFT_ACK);
+		break;
+	case PIM_MSG_TYPE_STATE_REFRESH:
+		return pim_staterefresh_recv(ifp, sg.src, pim_msg + PIM_MSG_HEADER_LEN,
+					     pim_msg_len - PIM_MSG_HEADER_LEN);
+		break;
+	case PIM_MSG_TYPE_GRAFT:
+		neigh = pim_neighbor_find(ifp, sg.src, false);
+		if (!neigh) {
+			if (PIM_DEBUG_PIM_PACKETS)
+				zlog_debug("%s %s: non-hello PIM message type=%d from non-neighbor %pPA on %s",
+					   __FILE__, __func__, header->type, &sg.src, ifp->name);
+			return -1;
+		}
+		pim_neighbor_timer_reset(neigh, neigh->holdtime);
+		rv = pim_graft_recv(ifp, neigh, sg.src, pim_msg + PIM_MSG_HEADER_LEN,
+				    pim_msg_len - PIM_MSG_HEADER_LEN, PIM_MSG_TYPE_GRAFT);
+
+		/* dm: send ack */
+		pim_ifp = ifp->info;
+		if (!pim_ifp->pim_passive_enable) {
+			pim_msg_build_header(sg.src, qpim_all_pim_routers_addr, pim_msg,
+					     pim_msg_len, PIM_MSG_TYPE_GRAFT_ACK, false);
+			pim_msg_send(pim_ifp->pim_sock_fd, pim_ifp->primary_address,
+				     qpim_all_pim_routers_addr, pim_msg, pim_msg_len, ifp);
+		}
+		return rv;
+		break;
 	case PIM_MSG_TYPE_JOIN_PRUNE:
 		neigh = pim_neighbor_find(ifp, sg.src, false);
 		if (!neigh) {
@@ -500,6 +572,7 @@ void pim_ifstat_reset(struct interface *ifp)
 	pim_ifp->pim_ifstat_join_recv = 0;
 	pim_ifp->pim_ifstat_join_send = 0;
 	pim_ifp->pim_ifstat_prune_recv = 0;
+	pim_ifp->pim_ifstat_graft_recv = 0;
 	pim_ifp->pim_ifstat_prune_send = 0;
 	pim_ifp->pim_ifstat_reg_recv = 0;
 	pim_ifp->pim_ifstat_reg_send = 0;
@@ -664,7 +737,7 @@ int pim_msg_send(int fd, pim_addr src, pim_addr dst, uint8_t *pim_msg,
 	if (ifp) {
 		struct pim_interface *pim_ifp = ifp->info;
 
-		if (pim_ifp->pim_passive_enable) {
+		if (pim_ifp && pim_ifp->pim_passive_enable) {
 			if (PIM_DEBUG_PIM_PACKETS)
 				zlog_debug("skip sending PIM message on passive interface %s",
 					   ifp->name);
@@ -694,12 +767,13 @@ int pim_msg_send(int fd, pim_addr src, pim_addr dst, uint8_t *pim_msg,
 	case PIM_MSG_TYPE_JOIN_PRUNE:
 	case PIM_MSG_TYPE_BOOTSTRAP:
 	case PIM_MSG_TYPE_ASSERT:
+	case PIM_MSG_TYPE_GRAFT:
+	case PIM_MSG_TYPE_STATE_REFRESH:
+	case PIM_MSG_TYPE_GRAFT_ACK:
 		ttl = 1;
 		break;
 	case PIM_MSG_TYPE_REGISTER:
 	case PIM_MSG_TYPE_REG_STOP:
-	case PIM_MSG_TYPE_GRAFT:
-	case PIM_MSG_TYPE_GRAFT_ACK:
 	case PIM_MSG_TYPE_CANDIDATE:
 		ttl = IPDEFTTL;
 		break;
@@ -843,7 +917,7 @@ static void hello_resched(struct interface *ifp)
 		zlog_debug("Rescheduling %d sec hello on interface %s",
 			   pim_ifp->pim_hello_period, ifp->name);
 	}
-	EVENT_OFF(pim_ifp->t_pim_hello_timer);
+	event_cancel(&pim_ifp->t_pim_hello_timer);
 	event_add_timer(router->master, on_pim_hello_send, ifp,
 			pim_ifp->pim_hello_period, &pim_ifp->t_pim_hello_timer);
 }
@@ -945,7 +1019,7 @@ void pim_hello_restart_triggered(struct interface *ifp)
 			return;
 		}
 
-		EVENT_OFF(pim_ifp->t_pim_hello_timer);
+		event_cancel(&pim_ifp->t_pim_hello_timer);
 	}
 
 	random_msec = triggered_hello_delay_msec;
