@@ -7,6 +7,7 @@
 #define PIM_SSM_H
 
 #define PIM_SSM_STANDARD_RANGE "232.0.0.0/8"
+#define PIM6_SSM_STANDARD_RANGE "FF30::/32"
 
 struct pim_instance;
 
@@ -26,6 +27,6 @@ void pim_ssm_prefix_list_update(struct pim_instance *pim,
 extern int pim_is_grp_ssm(struct pim_instance *pim, pim_addr group_addr);
 int pim_ssm_range_set(struct pim_instance *pim, vrf_id_t vrf_id,
 		      const char *plist_name);
-void *pim_ssm_init(void);
-void pim_ssm_terminate(struct pim_ssm *ssm);
+void pim_ssm_init(struct pim_instance *pim);
+void pim_ssm_terminate(struct pim_instance *pim);
 #endif
