@@ -1,21 +1,8 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
 /*
  * Static NHT code.
  * Copyright (C) 2018 Cumulus Networks, Inc.
  *               Donald Sharp
- *
- * This program is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the Free
- * Software Foundation; either version 2 of the License, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
- * more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; see the file COPYING; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 #include <zebra.h>
 
@@ -31,10 +18,10 @@
 #include "static_nht.h"
 
 static void static_nht_update_path(struct static_path *pn, struct prefix *nhp,
-				   uint32_t nh_num, vrf_id_t nh_vrf_id,
-				   struct vrf *vrf)
+				   uint32_t nh_num, vrf_id_t nh_vrf_id)
 {
 	struct static_nexthop *nh;
+	bool route_changed = false;
 
 	frr_each(static_nexthop_list, &pn->nexthop_list, nh) {
 		if (nh->nh_vrf_id != nh_vrf_id)
@@ -56,82 +43,72 @@ static void static_nht_update_path(struct static_path *pn, struct prefix *nhp,
 			nh->nh_valid = !!nh_num;
 
 		if (nh->state == STATIC_START)
-			static_zebra_route_add(pn, true);
+			route_changed = true;
 	}
+	if (route_changed)
+		static_zebra_route_add(pn, true);
 }
 
-static void static_nht_update_safi(struct prefix *sp, struct prefix *nhp,
-				   uint32_t nh_num, afi_t afi, safi_t safi,
-				   struct vrf *vrf, vrf_id_t nh_vrf_id)
+static void static_nht_update_safi(const struct prefix *sp, const struct prefix *ssrc_p,
+				   struct prefix *nhp, uint32_t nh_num, afi_t afi, safi_t safi,
+				   struct static_vrf *svrf, vrf_id_t nh_vrf_id)
 {
 	struct route_table *stable;
-	struct static_vrf *svrf;
 	struct route_node *rn;
 	struct static_path *pn;
 	struct static_route_info *si;
 
-	svrf = vrf->info;
-	if (!svrf)
-		return;
-
 	stable = static_vrf_static_table(afi, safi, svrf);
 	if (!stable)
 		return;
 
 	if (sp) {
-		rn = srcdest_rnode_lookup(stable, sp, NULL);
+		rn = srcdest_rnode_lookup(stable, sp, (const struct prefix_ipv6 *)ssrc_p);
 		if (rn && rn->info) {
 			si = static_route_info_from_rnode(rn);
 			frr_each(static_path_list, &si->path_list, pn) {
 				static_nht_update_path(pn, nhp, nh_num,
-						       nh_vrf_id, vrf);
+						       nh_vrf_id);
 			}
 			route_unlock_node(rn);
 		}
 		return;
 	}
 
-	for (rn = route_top(stable); rn; rn = route_next(rn)) {
+	for (rn = route_top(stable); rn; rn = srcdest_route_next(rn)) {
 		si = static_route_info_from_rnode(rn);
 		if (!si)
 			continue;
 		frr_each(static_path_list, &si->path_list, pn) {
-			static_nht_update_path(pn, nhp, nh_num, nh_vrf_id, vrf);
+			static_nht_update_path(pn, nhp, nh_num, nh_vrf_id);
 		}
 	}
 }
 
-void static_nht_update(struct prefix *sp, struct prefix *nhp, uint32_t nh_num,
-		       afi_t afi, safi_t safi, vrf_id_t nh_vrf_id)
+void static_nht_update(const struct prefix *sp, const struct prefix *ssrc_p, struct prefix *nhp,
+		       uint32_t nh_num, afi_t afi, safi_t safi, vrf_id_t nh_vrf_id)
 {
+	struct static_vrf *svrf;
 
-	struct vrf *vrf;
-
-	RB_FOREACH (vrf, vrf_name_head, &vrfs_by_name)
-		static_nht_update_safi(sp, nhp, nh_num, afi, safi, vrf,
-				       nh_vrf_id);
+	RB_FOREACH (svrf, svrf_name_head, &svrfs)
+		static_nht_update_safi(sp, ssrc_p, nhp, nh_num, afi, safi, svrf, nh_vrf_id);
 }
 
 static void static_nht_reset_start_safi(struct prefix *nhp, afi_t afi,
-					safi_t safi, struct vrf *vrf,
+					safi_t safi, struct static_vrf *svrf,
 					vrf_id_t nh_vrf_id)
 {
-	struct static_vrf *svrf;
 	struct route_table *stable;
 	struct static_nexthop *nh;
 	struct static_path *pn;
 	struct route_node *rn;
 	struct static_route_info *si;
 
-	svrf = vrf->info;
-	if (!svrf)
-		return;
-
 	stable = static_vrf_static_table(afi, safi, svrf);
 	if (!stable)
 		return;
 
-	for (rn = route_top(stable); rn; rn = route_next(rn)) {
+	for (rn = route_top(stable); rn; rn = srcdest_route_next(rn)) {
 		si = static_route_info_from_rnode(rn);
 		if (!si)
 			continue;
@@ -166,14 +143,14 @@ static void static_nht_reset_start_safi(struct prefix *nhp, afi_t afi,
 void static_nht_reset_start(struct prefix *nhp, afi_t afi, safi_t safi,
 			    vrf_id_t nh_vrf_id)
 {
-	struct vrf *vrf;
+	struct static_vrf *svrf;
 
-	RB_FOREACH (vrf, vrf_name_head, &vrfs_by_name)
-		static_nht_reset_start_safi(nhp, afi, safi, vrf, nh_vrf_id);
+	RB_FOREACH (svrf, svrf_name_head, &svrfs)
+		static_nht_reset_start_safi(nhp, afi, safi, svrf, nh_vrf_id);
 }
 
-static void static_nht_mark_state_safi(struct prefix *sp, afi_t afi,
-				       safi_t safi, struct vrf *vrf,
+static void static_nht_mark_state_safi(const struct prefix *sp, const struct prefix *ssrc_p,
+				       afi_t afi, safi_t safi, struct vrf *vrf,
 				       enum static_install_states state)
 {
 	struct static_vrf *svrf;
@@ -191,7 +168,7 @@ static void static_nht_mark_state_safi(struct prefix *sp, afi_t afi,
 	if (!stable)
 		return;
 
-	rn = srcdest_rnode_lookup(stable, sp, NULL);
+	rn = srcdest_rnode_lookup(stable, sp, (const struct prefix_ipv6 *)ssrc_p);
 	if (!rn)
 		return;
 	si = rn->info;
@@ -206,8 +183,8 @@ static void static_nht_mark_state_safi(struct prefix *sp, afi_t afi,
 	route_unlock_node(rn);
 }
 
-void static_nht_mark_state(struct prefix *sp, safi_t safi, vrf_id_t vrf_id,
-			   enum static_install_states state)
+void static_nht_mark_state(const struct prefix *sp, const struct prefix *ssrc_p, safi_t safi,
+			   vrf_id_t vrf_id, enum static_install_states state)
 {
 	struct vrf *vrf;
 
@@ -220,5 +197,5 @@ void static_nht_mark_state(struct prefix *sp, safi_t safi, vrf_id_t vrf_id,
 	if (!vrf || !vrf->info)
 		return;
 
-	static_nht_mark_state_safi(sp, afi, safi, vrf, state);
+	static_nht_mark_state_safi(sp, ssrc_p, afi, safi, vrf, state);
 }
