@@ -81,8 +81,7 @@ def setup_module(mod):
 
     for rname, router in router_list.items():
         router.load_config(
-            TopoRouter.RD_ZEBRA,
-            os.path.join(CWD, "{}/zebra.conf".format(rname))
+            TopoRouter.RD_ZEBRA, os.path.join(CWD, "{}/zebra.conf".format(rname))
         )
         router.load_config(
             TopoRouter.RD_BFD, os.path.join(CWD, "{}/bfdd.conf".format(rname))
@@ -114,8 +113,8 @@ def test_bfd_connection():
     if tgen.routers_have_failure():
         pytest.skip(tgen.errors)
     logger.info("waiting for bfd peers to go up")
-    router = tgen.gears['r1']
-    json_file = "{}/{}/bfd_peers_status.json".format(CWD, 'r1')
+    router = tgen.gears["r1"]
+    json_file = "{}/{}/bfd_peers_status.json".format(CWD, "r1")
     expected = json.loads(open(json_file).read())
 
     test_func = partial(
