@@ -52,6 +52,7 @@ from lib.common_config import (
     create_static_routes,
     check_router_status,
 )
+from lib.checkping import check_ping
 
 # Save the Current Working Directory to find configuration files.
 CWD = os.path.dirname(os.path.realpath(__file__))
@@ -1556,15 +1557,7 @@ def test_verify_default_originate_with_2way_ecmp_p2(request):
 
     step("Ping R1 configure IPv4 and IPv6 loopback address from R2")
     pingaddr = topo["routers"]["r1"]["links"]["lo"]["ipv4"].split("/")[0]
-    router = tgen.gears["r2"]
-
-    def ping_router():
-        output = router.run("ping -c 4 -w 4 {}".format(pingaddr))
-        logger.info(output)
-        if " 0% packet loss" not in output:
-            return False
-
-    _, res = topotest.run_and_expect(ping_router, None, count=10, wait=1)
+    check_ping("r2", pingaddr, True, 10, 1)
     logger.info("Ping from R1 to R2 ... success")
 
     step("Shuting up the active route")
@@ -1578,6 +1571,10 @@ def test_verify_default_originate_with_2way_ecmp_p2(request):
         if ipv_dict["ipv4"] == ipv4_address and ipv_dict["ipv6"] == ipv6_address:
             active_interface = dut_links[key]["interface"]
 
+    if active_interface == None:
+        logger.info("The v4 and v6 best paths do not use the same neighbors on r2, we are skipping the rest of this test")
+        return
+
     logger.info(
         "Shutting down the interface {} on router {} ".format(active_interface, "r1")
     )
@@ -1627,9 +1624,7 @@ def test_verify_default_originate_with_2way_ecmp_p2(request):
 
     step("Ping R1 configure IPv4 and IPv6 loopback address from R2")
     pingaddr = topo["routers"]["r1"]["links"]["lo"]["ipv4"].split("/")[0]
-    router = tgen.gears["r2"]
-    output = router.run("ping -c 4 -w 4 {}".format(pingaddr))
-    assert " 0% packet loss" in output, "Ping R1->R2  FAILED"
+    check_ping("r2", pingaddr, True, 10, 1)
     logger.info("Ping from R1 to R2 ... success")
 
     step("No Shuting up the active route")
