@@ -53,7 +53,39 @@ anycast IP (VIP) addresses via BGP.
 
 
 def build_topo(tgen):
-    "Build function"
+    """
+    Build function
+
+                                               +------+
+                                               |      |
+                                              /|  r7  |---
+                                             / | 65351|
+                                            /  +------+
+                                           /
+                                 +------+ /    +------+
+                                 |      |/     |      |
+                                /|  r4  |      |  r8  |---
+                               / | 65301|------| 65352|
+                              /  +------+      +------+
+                             /
+                   +------+ /    +------+      +------+
+                   |      |/     |      |      |      |
+                   |  r2  |      |  r5  |      |  r9  |---
+                   | 65201|------| 65302|------| 65353|
+                   +------+      +------+      +------+
+                      |
+     +------+         |
+     |      |----------
+     |  r1  |
+     | 65101|----------
+     +------+         |
+                      |
+                   +------+      +------+      +------+
+                   |      |      |      |      |      |
+                   |  r3  |------|  r6  |------|  r10 |---
+                   | 65202|      | 65303|      | 65354|
+                   +------+      +------+      +------+
+    """
 
     # Create 10 routers - 1 super-spine, 2 spines, 3 leafs
     # and 4 servers
