@@ -108,6 +108,8 @@ def _router_json_cmp_exact_filter(router, cmd, expected):
                 attr.pop("prefixLen")
             if "asPath" in attr:
                 attr.pop("asPath")
+            if "receivedNexthopGroupId" in attr:
+                attr.pop("receivedNexthopGroupId")
             for nexthop in attr.get("nexthops", []):
                 if "flags" in nexthop:
                     nexthop.pop("flags")
@@ -149,7 +151,7 @@ def _check_zebra_rib_r1(with_redistributed_route, with_second_route=False):
         "show ip route bgp json",
         expected,
     )
-    _, result = topotest.run_and_expect(test_func, None, count=10, wait=0.5)
+    _, result = topotest.run_and_expect(test_func, None, count=15, wait=1)
     assertmsg = '"{}" JSON output mismatches'.format(router.name)
     assert result is None, assertmsg
 
@@ -226,7 +228,7 @@ def test_step5_no_redistribute_table_2200():
         pytest.skip(tgen.errors)
 
     tgen.gears["r2"].vtysh_cmd(
-        "configure terminal\nrouter bgp 65501\naddress-family ipv4 unicast\nno redistribute table-direct\n"
+        "configure terminal\nrouter bgp 65501\naddress-family ipv4 unicast\nno redistribute table-direct 2200\n"
     )
 
     step("r2, check that the 'redistribute' command is not configured")
