@@ -77,6 +77,7 @@ from lib.common_config import (
     required_linux_kernel_version,
     create_interface_in_kernel,
 )
+from lib.checkping import check_ping
 
 pytestmark = [pytest.mark.isisd, pytest.mark.sharpd]
 
@@ -237,22 +238,6 @@ def router_compare_json_output(rname, command, reference):
     assert diff is None, assertmsg
 
 
-def check_ping6(name, dest_addr, expect_connected):
-    def _check(name, dest_addr, match):
-        tgen = get_topogen()
-        output = tgen.gears[name].run("ping6 {} -c 1 -w 1".format(dest_addr))
-        logger.info(output)
-        if match not in output:
-            return "ping fail"
-
-    match = "{} packet loss".format(", 0%" if expect_connected else ", 100%")
-    logger.info("[+] check {} {} {}".format(name, dest_addr, match))
-    tgen = get_topogen()
-    func = functools.partial(_check, name, dest_addr, match)
-    _, result = topotest.run_and_expect(func, None, count=10, wait=1)
-    assert result is None, "Failed"
-
-
 #
 # Step 1
 #
@@ -343,7 +328,7 @@ def test_ping_step1():
     )
 
     # Try to ping dst from rt1
-    check_ping6("rt1", "fc00:0:9::1", True)
+    check_ping("rt1", "fc00:0:9::1", True, 10, 1)
 
 
 #
@@ -444,7 +429,7 @@ def test_ping_step2():
         pytest.skip(tgen.errors)
 
     # ping should pass because route to fc00:0:2:6:f00d:: is still valid
-    check_ping6("rt1", "fc00:0:9::1", True)
+    check_ping("rt1", "fc00:0:9::1", True, 10, 1)
 
 
 #
@@ -546,7 +531,7 @@ def test_ping_step3():
     if tgen.routers_have_failure():
         pytest.skip(tgen.errors)
 
-    check_ping6("rt1", "fc00:0:9::1", True)
+    check_ping("rt1", "fc00:0:9::1", True, 10, 1)
 
 
 #
@@ -645,7 +630,7 @@ def test_ping_step4():
         pytest.skip(tgen.errors)
 
     # ping should pass because route to fc00:0:2:6:f00d:: is still valid
-    check_ping6("rt1", "fc00:0:9::1", True)
+    check_ping("rt1", "fc00:0:9::1", True, 10, 1)
 
 
 #
@@ -743,7 +728,7 @@ def test_ping_step5():
     if tgen.routers_have_failure():
         pytest.skip(tgen.errors)
 
-    check_ping6("rt1", "fc00:0:9::1", True)
+    check_ping("rt1", "fc00:0:9::1", True, 10, 1)
 
 
 #
@@ -841,7 +826,7 @@ def test_ping_step6():
         pytest.skip(tgen.errors)
 
     # ping should pass because route to fc00:0:2:6:f00d:: is still valid
-    check_ping6("rt1", "fc00:0:9::1", True)
+    check_ping("rt1", "fc00:0:9::1", True, 10, 1)
 
 
 #
@@ -939,7 +924,7 @@ def test_ping_step7():
     if tgen.routers_have_failure():
         pytest.skip(tgen.errors)
 
-    check_ping6("rt1", "fc00:0:9::1", True)
+    check_ping("rt1", "fc00:0:9::1", True, 10, 1)
 
 
 #
@@ -1037,7 +1022,7 @@ def test_ping_step8():
         pytest.skip(tgen.errors)
 
     # ping should pass because route to fc00:0:2:6:f00d:: is still valid
-    check_ping6("rt1", "fc00:0:9::1", True)
+    check_ping("rt1", "fc00:0:9::1", True, 10, 1)
 
 
 #
@@ -1138,7 +1123,7 @@ def test_ping_step9():
     if tgen.routers_have_failure():
         pytest.skip(tgen.errors)
 
-    check_ping6("rt1", "fc00:0:9::1", True)
+    check_ping("rt1", "fc00:0:9::1", True, 10, 1)
 
 
 # Memory leak test template
