@@ -31,7 +31,7 @@ PATH_ATTR_TYPE_MP_UNREACH_NLRI = 15
 PATH_ATTR_TYPE_EXTENDED_COMMUNITIES = 16
 PATH_ATTR_TYPE_AS4_PATH = 17
 PATH_ATTR_TYPE_AS4_AGGREGATOR = 18
-PATH_ATTR_TYEP_PMSI_TUNNEL_ATTRIBUTE = 22
+PATH_ATTR_TYPE_PMSI_TUNNEL_ATTRIBUTE = 22
 
 ORIGIN_IGP = 0x00
 ORIGIN_EGP = 0x01
