@@ -1,24 +1,11 @@
 #!/usr/bin/python
+# SPDX-License-Identifier: ISC
 
 #
 # Copyright (c) 2020 by VMware, Inc. ("VMware")
 # Used Copyright (c) 2018 by Network Device Education Foundation,
 # Inc. ("NetDEF") in this file.
 #
-# Permission to use, copy, modify, and/or distribute this software
-# for any purpose with or without fee is hereby granted, provided
-# that the above copyright notice and this permission notice appear
-# in all copies.
-#
-# THE SOFTWARE IS PROVIDED "AS IS" AND VMWARE DISCLAIMS ALL WARRANTIES
-# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL VMWARE BE LIABLE FOR
-# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY
-# DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
-# WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
-# ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE
-# OF THIS SOFTWARE.
-#
 
 
 """
@@ -163,7 +150,7 @@ def setup_module(mod):
     logger.info("Running setup_module() done")
 
 
-def teardown_module(mod):
+def teardown_module():
     """
     Teardown the pytest environment
 
@@ -240,13 +227,13 @@ def test_static_rte_with_8ecmp_nh_p1_tc9_ebgp(request):
     if tgen.routers_have_failure():
         pytest.skip(tgen.errors)
     NEXT_HOP_IP = populate_nh()
-    step("Configure 8 interfaces / links between R1 and R2")
-    step("Configure 8 interfaces / links between R2 and R3")
-    step("Configure 8 IBGP IPv4 peering between R2 and R3 router.")
+    step("TC9: Configure 8 interfaces / links between R1 and R2")
+    step("TC9: Configure 8 interfaces / links between R2 and R3")
+    step("TC9: Configure 8 IBGP IPv4 peering between R2 and R3 router.")
     reset_config_on_routers(tgen)
 
     step(
-        "Configure 8 IPv4 static route in R2 with 8 next hop"
+        "TC9: Configure 8 IPv4 static route in R2 with 8 next hop"
         "N1(21.1.1.2) , N2(22.1.1.2) , N3(23.1.1.2) , N4(24.1.1.2) ,"
         "N5(25.1.1.2) , N6(26.1.1.2) , N7(27.1.1.2) , N8(28.1.1.2) ,"
         "Static route next-hop present on R1"
@@ -294,9 +281,9 @@ def test_static_rte_with_8ecmp_nh_p1_tc9_ebgp(request):
         )
         assert (
             result is True
-        ), "Testcase {} : Failed \nError: Routes are" " missing in RIB".format(tc_name)
+        ), "Testcase {} : Failed \nError: Routes are  missing in RIB".format(tc_name)
 
-    step("Configure redistribute static in BGP on R2 router")
+    step("TC9: Configure redistribute static in BGP on R2 router")
     for addr_type in ADDR_TYPES:
         input_dict_2 = {
             "r2": {
@@ -319,16 +306,16 @@ def test_static_rte_with_8ecmp_nh_p1_tc9_ebgp(request):
         result = verify_bgp_rib(tgen, addr_type, dut, input_dict_4)
         assert (
             result is True
-        ), "Testcase {} : Failed \nError: Routes are" " missing in RIB".format(tc_name)
+        ), "Testcase {} : Failed \nError: Routes are  missing in RIB".format(tc_name)
 
     step(
-        "Remove the static route configured with nexthop N1 to N8, one"
+        "TC9: Remove the static route configured with nexthop N1 to N8, one"
         "by one from running config"
     )
     dut = "r2"
     protocol = "static"
     step(
-        "After removing the static route with N1 to N8 one by one , "
+        "TC9: After removing the static route with N1 to N8 one by one , "
         "verify that entry is removed from RIB and FIB of R3 "
     )
     for addr_type in ADDR_TYPES:
@@ -351,7 +338,7 @@ def test_static_rte_with_8ecmp_nh_p1_tc9_ebgp(request):
             )
 
             step(
-                "After removing the static route with N1 to N8 one by one , "
+                "TC9: After removing the static route with N1 to N8 one by one , "
                 "verify that entry is removed from RIB and FIB of R3 "
             )
             nh = NEXT_HOP_IP["nh" + str(nhp)][addr_type]
@@ -366,11 +353,11 @@ def test_static_rte_with_8ecmp_nh_p1_tc9_ebgp(request):
             )
             assert (
                 result is not True
-            ), "Testcase {} : Failed\nError: Routes is" " still present in RIB".format(
+            ), "Testcase {} : Failed\nError:  routes are  still present in RIB".format(
                 tc_name
             )
 
-    step("Configure the static route with nexthop N1 to N8, one by one")
+    step("TC9: Configure the static route with nexthop N1 to N8, one by one")
     for addr_type in ADDR_TYPES:
         for nhp in range(1, 9):
             input_dict_4 = {
@@ -395,28 +382,26 @@ def test_static_rte_with_8ecmp_nh_p1_tc9_ebgp(request):
             )
             assert (
                 result is True
-            ), "Testcase {} : Failed\nError: Routes are" " missing in RIB".format(
-                tc_name
-            )
+            ), "Testcase {} : Failed\nError: Routes are  missing in RIB".format(tc_name)
 
     protocol = "static"
-    step("Random shut of the nexthop interfaces")
+    step("TC9: Random shut of the nexthop interfaces")
     randnum = random.randint(0, 7)
     # Shutdown interface
     dut = "r2"
     step(
-        " interface which is about to be shut no shut between r1 and r2 is " "%s",
+        "TC9: Interface which is about to be shut no shut between r1 and r2 is  %s",
         topo["routers"]["r2"]["links"]["r1-link{}".format(randnum)]["interface"],
     )
     intf = topo["routers"]["r2"]["links"]["r1-link{}".format(randnum)]["interface"]
     shutdown_bringup_interface(tgen, dut, intf, False)
 
-    step("Random no shut of the nexthop interfaces")
+    step("TC9: Random no shut of the nexthop interfaces")
     # Bringup interface
     shutdown_bringup_interface(tgen, dut, intf, True)
 
     step(
-        "After random shut/no shut of nexthop , only that "
+        "TC9: After random shut/no shut of nexthop , only that "
         "nexthop deleted/added from all the routes , other nexthop remain "
         "unchanged"
     )
@@ -443,9 +428,9 @@ def test_static_rte_with_8ecmp_nh_p1_tc9_ebgp(request):
     )
     assert (
         result is True
-    ), "Testcase {} : Failed \nError: Routes are" " missing in RIB".format(tc_name)
+    ), "Testcase {} : Failed \nError: Routes are  missing in RIB".format(tc_name)
 
-    step("Remove random static route with all the nexthop")
+    step("TC9: Remove random static route with all the nexthop")
     dut = "r2"
     randnum = random.randint(1, 7)
     for addr_type in ADDR_TYPES:
@@ -467,7 +452,7 @@ def test_static_rte_with_8ecmp_nh_p1_tc9_ebgp(request):
         )
 
         step(
-            "After delete of random route , that route only got deleted from"
+            "TC9: After delete of random route , that route only got deleted from"
             " RIB/FIB other route are showing properly"
         )
         nh = NEXT_HOP_IP["nh{}".format(randnum)][addr_type]
@@ -482,7 +467,7 @@ def test_static_rte_with_8ecmp_nh_p1_tc9_ebgp(request):
         )
         assert (
             result is not True
-        ), "Testcase {} : Failed \nError: Routes are" " missing in RIB".format(tc_name)
+        ), "Testcase {} : Failed \nError: Routes are  missing in RIB".format(tc_name)
 
     for addr_type in ADDR_TYPES:
         input_dict_4 = {
@@ -501,13 +486,13 @@ def test_static_rte_with_8ecmp_nh_p1_tc9_ebgp(request):
             tc_name, result
         )
 
-    step("Reload the FRR router")
+    step("TC9: Reload the FRR router")
     # stop/start -> restart FRR router and verify
     stop_router(tgen, "r2")
     start_router(tgen, "r2")
 
     step(
-        "After reload of FRR router , static route "
+        "TC9: After reload of FRR router , static route "
         "installed in RIB and FIB properly ."
     )
     for addr_type in ADDR_TYPES:
@@ -536,9 +521,9 @@ def test_static_rte_with_8ecmp_nh_p1_tc9_ebgp(request):
         )
         assert (
             result is True
-        ), "Testcase {} : Failed \nError: Routes are" " missing in RIB".format(tc_name)
+        ), "Testcase {} : Failed \nError: Routes are  missing in RIB".format(tc_name)
 
-    step("Remove the redistribute static knob")
+    step("TC9: Remove the redistribute static knob")
     for addr_type in ADDR_TYPES:
         input_dict_2 = {
             "r2": {
@@ -561,7 +546,7 @@ def test_static_rte_with_8ecmp_nh_p1_tc9_ebgp(request):
         )
 
         step(
-            "After removing the BGP neighbor or redistribute static knob , "
+            "TC9: After removing the BGP neighbor or redistribute static knob , "
             "verify route got clear from RIB and FIB of R3 routes "
         )
         dut = "r3"
@@ -571,7 +556,7 @@ def test_static_rte_with_8ecmp_nh_p1_tc9_ebgp(request):
         )
         assert (
             result is not True
-        ), "Testcase {} : Failed \nError: Routes are" " still present in RIB".format(
+        ), "Testcase {} : Failed \nError: Routes are  still present in RIB".format(
             tc_name
         )
 
@@ -591,13 +576,13 @@ def test_static_route_8nh_diff_AD_bgp_ecmp_p1_tc6_ebgp(request):
     if tgen.routers_have_failure():
         pytest.skip(tgen.errors)
 
-    step("Configure 8 interfaces / links between R1 and R2 ,")
-    step("Configure 8 interlaces/links between R2 and R3")
+    step("TC6: Configure 8 interfaces / links between R1 and R2 for IBGP test")
+    step("TC6: Configure 8 interlaces/links between R2 and R3 for IBGP test")
     step(
-        "Configure IBGP IPv4 peering over loopback interface between"
-        "R2 and R3 router."
+        "TC6: Configure IBGP IPv4 peering over loopback interface between"
+        "R2 and R3 router for IBGP test."
     )
-    step("Configure redistribute static in BGP on R2 router")
+    step("TC6: Configure redistribute static in BGP on R2 router for IBGP test")
     reset_config_on_routers(tgen)
     NEXT_HOP_IP = populate_nh()
     nh_all = {}
@@ -606,7 +591,7 @@ def test_static_route_8nh_diff_AD_bgp_ecmp_p1_tc6_ebgp(request):
         for nhp in range(1, 9):
             nh_all[addr_type].append(NEXT_HOP_IP["nh" + str(nhp)][addr_type])
     step(
-        "Configure IPv4 static route in R2 with 8 next hop"
+        "TC6: Configure IPv4 static route in R2 with 8 next hop"
         "N1(21.1.1.2) AD 10, N2(22.1.1.2) AD 20, N3(23.1.1.2) AD 30,"
         "N4(24.1.1.2) AD 40, N5(25.1.1.2) AD 50, N6(26.1.1.2) AD 60,"
         "N7(27.1.1.2) AD 70, N8(28.1.1.2) AD 80, Static route next-hop"
@@ -633,7 +618,7 @@ def test_static_route_8nh_diff_AD_bgp_ecmp_p1_tc6_ebgp(request):
         logger.info("Verifying %s routes on r2", addr_type)
 
         step(
-            "On R2, static route installed in RIB using "
+            "TC6: On R2, static route installed in RIB using "
             "show ip route with 8 next hop , lowest AD nexthop is active"
         )
         input_dict_4 = {
@@ -655,7 +640,7 @@ def test_static_route_8nh_diff_AD_bgp_ecmp_p1_tc6_ebgp(request):
         )
         assert (
             result is True
-        ), "Testcase {} : Failed \nError: Routes are" " missing in RIB".format(tc_name)
+        ), "Testcase {} : Failed \nError: Routes are  missing in RIB".format(tc_name)
 
         nh = []
         for nhp in range(2, 9):
@@ -673,10 +658,10 @@ def test_static_route_8nh_diff_AD_bgp_ecmp_p1_tc6_ebgp(request):
         )
         assert (
             result is not True
-        ), "Testcase {} : Failed \nError: Routes " " are missing in RIB".format(tc_name)
+        ), "Testcase {} : Failed \nError: Routes   are missing in RIB".format(tc_name)
 
     step(
-        "Remove the static route configured with nexthop N1 to N8, one"
+        "TC6: Remove the static route configured with nexthop N1 to N8, one"
         "by one from running config"
     )
 
@@ -718,11 +703,9 @@ def test_static_route_8nh_diff_AD_bgp_ecmp_p1_tc6_ebgp(request):
     )
     assert (
         result is not True
-    ), "Testcase {} : Failed \nError: Routes are" " still present in RIB".format(
-        tc_name
-    )
+    ), "Testcase {} : Failed \nError: Routes are  still present in RIB".format(tc_name)
 
-    step("Configure the static route with nexthop N1 to N8, one by one")
+    step("TC6: Configure the static route with nexthop N1 to N8, one by one")
 
     for addr_type in ADDR_TYPES:
         # add static routes
@@ -745,7 +728,7 @@ def test_static_route_8nh_diff_AD_bgp_ecmp_p1_tc6_ebgp(request):
         )
 
     step(
-        " After configuring them, route is always active with lowest AD"
+        "TC6: After configuring them, route is always active with lowest AD"
         " value and all the nexthop populated in RIB and FIB again"
     )
     for addr_type in ADDR_TYPES:
@@ -768,7 +751,7 @@ def test_static_route_8nh_diff_AD_bgp_ecmp_p1_tc6_ebgp(request):
         )
         assert (
             result is True
-        ), "Testcase {} : Failed \nError: Routes are" " missing in RIB".format(tc_name)
+        ), "Testcase {} : Failed \nError: Routes are  missing in RIB".format(tc_name)
         nh = []
         for nhp in range(2, 9):
             nh.append(NEXT_HOP_IP["nh" + str(nhp)][addr_type])
@@ -785,9 +768,9 @@ def test_static_route_8nh_diff_AD_bgp_ecmp_p1_tc6_ebgp(request):
         )
         assert (
             result is not True
-        ), "Testcase {} : Failed \nError: Routes " " are missing in RIB".format(tc_name)
+        ), "Testcase {} : Failed \nError: Routes   are missing in RIB".format(tc_name)
 
-    step("Random shut of the nexthop interfaces")
+    step("TC6: Random shut of the nexthop interfaces")
     randnum = random.randint(0, 7)
     for addr_type in ADDR_TYPES:
         intf = topo["routers"]["r2"]["links"]["r1-link" + str(randnum)]["interface"]
@@ -814,11 +797,11 @@ def test_static_route_8nh_diff_AD_bgp_ecmp_p1_tc6_ebgp(request):
         )
         assert (
             result is not True
-        ), "Testcase {} : Failed \n" "Error: Routes are still present in RIB".format(
+        ), "Testcase {} : Failed \n Error: Routes are still present in RIB".format(
             tc_name
         )
 
-    step("Random no shut of the nexthop interfaces")
+    step("TC6: Random no shut of the nexthop interfaces")
     for addr_type in ADDR_TYPES:
         intf = topo["routers"]["r2"]["links"]["r1-link" + str(randnum)]["interface"]
         shutdown_bringup_interface(tgen, dut, intf, True)
@@ -828,7 +811,7 @@ def test_static_route_8nh_diff_AD_bgp_ecmp_p1_tc6_ebgp(request):
         )
         assert (
             result is True
-        ), "Testcase {} : Failed \n" "Error: Routes are missing in RIB".format(tc_name)
+        ), "Testcase {} : Failed \n Error: Routes are missing in RIB".format(tc_name)
 
     dut = "r2"
     protocol = "static"
@@ -837,7 +820,7 @@ def test_static_route_8nh_diff_AD_bgp_ecmp_p1_tc6_ebgp(request):
         result = verify_rib(tgen, addr_type, dut, input_dict_4, protocol=protocol)
         assert (
             result is True
-        ), "Testcase {}: Failed \n " "Error: Routes are missing in RIB".format(tc_name)
+        ), "Testcase {}: Failed \n  Error: Routes are missing in RIB".format(tc_name)
 
     protocol = "bgp"
     dut = "r3"
@@ -846,9 +829,9 @@ def test_static_route_8nh_diff_AD_bgp_ecmp_p1_tc6_ebgp(request):
         result = verify_rib(tgen, addr_type, dut, input_dict_4, protocol=protocol)
         assert (
             result is True
-        ), "Testcase {}: Failed \n " "Error: Routes are missing in RIB".format(tc_name)
+        ), "Testcase {}: Failed \n  Error: Routes are missing in RIB".format(tc_name)
 
-    step("Reload the FRR router")
+    step("TC6: Reload the FRR router")
     # stop/start -> restart FRR router and verify
     stop_router(tgen, "r2")
 
@@ -859,7 +842,7 @@ def test_static_route_8nh_diff_AD_bgp_ecmp_p1_tc6_ebgp(request):
         result = verify_rib(tgen, addr_type, dut, input_dict_4, protocol=protocol)
         assert (
             result is True
-        ), "Testcase {} : Failed \n" "Error: Routes are still present in RIB".format(
+        ), "Testcase {} : Failed \n Error: Routes are still present in RIB".format(
             tc_name
         )
 
@@ -878,14 +861,14 @@ def test_static_route_8nh_diff_AD_ebgp_ecmp_p1_tc8_ebgp(request):
     if tgen.routers_have_failure():
         pytest.skip(tgen.errors)
 
-    step("Configure 8 interfaces / links between R1 and R2")
-    step("Configure 8 interlaces/links between R2 and R3")
-    step("Configure 8 EBGP IPv4 peering between R2 and R3")
+    step("TC8: Configure 8 interfaces / links between R1 and R2 for EBGP test")
+    step("TC8: Configure 8 interlaces/links between R2 and R3 for EBGP test")
+    step("TC8: Configure 8 EBGP IPv4 peering between R2 and R3 for EBGP test")
 
     reset_config_on_routers(tgen)
     NEXT_HOP_IP = populate_nh()
 
-    step("Configure redistribute static in BGP on R2 router")
+    step("TC8: Configure redistribute static in BGP on R2 router for EBGP test")
     for addr_type in ADDR_TYPES:
         input_dict_2 = {
             "r2": {
@@ -958,7 +941,7 @@ def test_static_route_8nh_diff_AD_ebgp_ecmp_p1_tc8_ebgp(request):
         )
         assert (
             result is True
-        ), "Testcase {} : Failed \nError: Routes are" " missing in RIB".format(tc_name)
+        ), "Testcase {} : Failed \nError: Routes are  missing in RIB".format(tc_name)
 
         nh = []
         for nhp in range(2, 9):
@@ -975,7 +958,7 @@ def test_static_route_8nh_diff_AD_ebgp_ecmp_p1_tc8_ebgp(request):
         )
         assert (
             result is not True
-        ), "Testcase {} : Failed \nError: Routes " " are missing in RIB".format(tc_name)
+        ), "Testcase {} : Failed \nError: Routes   are missing in RIB".format(tc_name)
 
     step(
         "Remove the static route configured with nexthop N1 to N8, one"
@@ -1020,11 +1003,9 @@ def test_static_route_8nh_diff_AD_ebgp_ecmp_p1_tc8_ebgp(request):
     )
     assert (
         result is not True
-    ), "Testcase {} : Failed \nError: Routes are" " still present in RIB".format(
-        tc_name
-    )
+    ), "Testcase {} : Failed \nError: Routes are  still present in RIB".format(tc_name)
 
-    step("Configure the static route with nexthop N1 to N8, one by one")
+    step("TC8: Configure the static route with nexthop N1 to N8, one by one")
 
     for addr_type in ADDR_TYPES:
         # add static routes
@@ -1047,7 +1028,7 @@ def test_static_route_8nh_diff_AD_ebgp_ecmp_p1_tc8_ebgp(request):
         )
 
     step(
-        " After configuring them, route is always active with lowest AD"
+        "TC8: After configuring them, route is always active with lowest AD"
         " value and all the nexthop populated in RIB and FIB again"
     )
     for addr_type in ADDR_TYPES:
@@ -1070,7 +1051,7 @@ def test_static_route_8nh_diff_AD_ebgp_ecmp_p1_tc8_ebgp(request):
         )
         assert (
             result is True
-        ), "Testcase {} : Failed \nError: Routes are" " missing in RIB".format(tc_name)
+        ), "Testcase {} : Failed \nError: Routes are  missing in RIB".format(tc_name)
         nh = []
         for nhp in range(2, 9):
             nh.append(NEXT_HOP_IP["nh" + str(nhp)][addr_type])
@@ -1086,9 +1067,9 @@ def test_static_route_8nh_diff_AD_ebgp_ecmp_p1_tc8_ebgp(request):
         )
         assert (
             result is not True
-        ), "Testcase {} : Failed \nError: Routes " " are missing in RIB".format(tc_name)
+        ), "Testcase {} : Failed \nError: Routes   are missing in RIB".format(tc_name)
 
-    step("Random shut of the nexthop interfaces")
+    step("TC8: Random shut of the nexthop interfaces")
     randnum = random.randint(0, 7)
     for addr_type in ADDR_TYPES:
         intf = topo["routers"]["r2"]["links"]["r1-link" + str(randnum)]["interface"]
@@ -1115,11 +1096,11 @@ def test_static_route_8nh_diff_AD_ebgp_ecmp_p1_tc8_ebgp(request):
         )
         assert (
             result is not True
-        ), "Testcase {} : Failed \n" "Error: Routes are still present in RIB".format(
+        ), "Testcase {} : Failed \n Error: Routes are still present in RIB".format(
             tc_name
         )
 
-    step("Random no shut of the nexthop interfaces")
+    step("TC8: Random no shut of the nexthop interfaces")
     for addr_type in ADDR_TYPES:
         intf = topo["routers"]["r2"]["links"]["r1-link" + str(randnum)]["interface"]
         shutdown_bringup_interface(tgen, dut, intf, True)
@@ -1129,12 +1110,12 @@ def test_static_route_8nh_diff_AD_ebgp_ecmp_p1_tc8_ebgp(request):
         )
         assert (
             result is True
-        ), "Testcase {} : Failed \n" "Error: Routes are missing in RIB".format(tc_name)
+        ), "Testcase {} : Failed \n Error: Routes are missing in RIB".format(tc_name)
 
     dut = "r2"
     protocol = "static"
 
-    step("Reload the FRR router")
+    step("TC8: Reload the FRR router")
     # stop/start -> restart FRR router and verify
     stop_router(tgen, "r2")
 
@@ -1145,7 +1126,7 @@ def test_static_route_8nh_diff_AD_ebgp_ecmp_p1_tc8_ebgp(request):
         result = verify_rib(tgen, addr_type, dut, input_dict_4, protocol=protocol)
         assert (
             result is True
-        ), "Testcase {} : Failed \n" "Error: Routes are still present in RIB".format(
+        ), "Testcase {} : Failed \n Error: Routes are still present in RIB".format(
             tc_name
         )
 
@@ -1244,9 +1225,9 @@ def test_static_route_8nh_diff_AD_bgp_ecmp_p1_tc10_ebgp(request):
         )
         assert (
             result is True
-        ), "Testcase {} : Failed \nError: Routes are" " missing in RIB".format(tc_name)
+        ), "Testcase {} : Failed \nError: Routes are  missing in RIB".format(tc_name)
 
-        step("Verify that highest AD nexthop are inactive")
+        step("TC10: Verify that highest AD nexthop are inactive")
         nh = []
         for nhp in range(2, 9):
             nh.append(NEXT_HOP_IP["nh" + str(nhp)][addr_type])
@@ -1263,9 +1244,9 @@ def test_static_route_8nh_diff_AD_bgp_ecmp_p1_tc10_ebgp(request):
         )
         assert (
             result is not True
-        ), "Testcase {} : Failed \nError: Routes " " are missing in RIB".format(tc_name)
+        ), "Testcase {} : Failed \nError: Routes   are missing in RIB".format(tc_name)
 
-    step("Configure redistribute static in BGP on R2 router")
+    step("TC10: Configure redistribute static in BGP on R2 router")
     for addr_type in ADDR_TYPES:
         input_dict_2 = {
             "r2": {
@@ -1327,11 +1308,11 @@ def test_static_route_8nh_diff_AD_bgp_ecmp_p1_tc10_ebgp(request):
         )
         assert (
             result is not True
-        ), "Testcase {} : Failed \nError: Routes are" " still present in RIB".format(
+        ), "Testcase {} : Failed \nError: Routes are  still present in RIB".format(
             tc_name
         )
 
-    step("Configure the static route with nexthop N1 to N8, one by one")
+    step("TC10: Configure the static route with nexthop N1 to N8, one by one")
     for addr_type in ADDR_TYPES:
         # add static routes
         for nhp in range(1, 9):
@@ -1354,19 +1335,11 @@ def test_static_route_8nh_diff_AD_bgp_ecmp_p1_tc10_ebgp(request):
         )
 
     step(
-        " After configuring them, route is always active with lowest AD"
+        "TC10: After configuring them, route is always active with lowest AD"
         " value and all the nexthop populated in RIB and FIB again"
     )
     for addr_type in ADDR_TYPES:
-        input_dict_4 = {
-            "r2": {
-                "static_routes": [
-                    {
-                        "network": PREFIX1[addr_type],
-                    }
-                ]
-            }
-        }
+        input_dict_4 = {"r2": {"static_routes": [{"network": PREFIX1[addr_type]}]}}
         nh = NEXT_HOP_IP["nh1"][addr_type]
         result = verify_rib(
             tgen, addr_type, dut, input_dict_4, next_hop=nh, protocol=protocol, fib=True
@@ -1376,7 +1349,7 @@ def test_static_route_8nh_diff_AD_bgp_ecmp_p1_tc10_ebgp(request):
             "lowest AD  is missing in RIB".format(tc_name)
         )
 
-    step("Random shut of the nexthop interfaces")
+    step("TC10: Random shut of the nexthop interfaces")
     randnum = random.randint(0, 7)
     for addr_type in ADDR_TYPES:
         intf = topo["routers"]["r2"]["links"]["r1-link" + str(randnum)]["interface"]
@@ -1403,11 +1376,11 @@ def test_static_route_8nh_diff_AD_bgp_ecmp_p1_tc10_ebgp(request):
         )
         assert (
             result is not True
-        ), "Testcase {} : Failed \n" "Error: Routes are still present in RIB".format(
+        ), "Testcase {} : Failed \n Error: Routes are still present in RIB".format(
             tc_name
         )
 
-    step("Random no shut of the nexthop interfaces")
+    step("TC10: Random no shut of the nexthop interfaces")
     for addr_type in ADDR_TYPES:
         intf = topo["routers"]["r2"]["links"]["r1-link" + str(randnum)]["interface"]
         shutdown_bringup_interface(tgen, dut, intf, True)
@@ -1417,9 +1390,9 @@ def test_static_route_8nh_diff_AD_bgp_ecmp_p1_tc10_ebgp(request):
         )
         assert (
             result is True
-        ), "Testcase {} : Failed \n" "Error: Routes are missing in RIB".format(tc_name)
+        ), "Testcase {} : Failed \n Error: Routes are missing in RIB".format(tc_name)
 
-    step("Remove random static route with all the nexthop")
+    step("TC10: Remove random static route with all the nexthop")
     for addr_type in ADDR_TYPES:
         # delete static routes
         for nhp in range(1, 9):
@@ -1507,9 +1480,7 @@ def test_static_route_8nh_diff_AD_bgp_ecmp_p1_tc10_ebgp(request):
             )
             assert (
                 result is True
-            ), "Testcase {} : Failed \nError: Route " " is missing in RIB".format(
-                tc_name
-            )
+            ), "Testcase {} : Failed \nError: Route   is missing in RIB".format(tc_name)
 
     write_test_footer(tc_name)
 
@@ -1605,9 +1576,9 @@ def test_static_route_delete_p0_tc11_ebgp(request):
         )
         assert (
             result is True
-        ), "Testcase {} : Failed \nError: Routes are" " missing in RIB".format(tc_name)
+        ), "Testcase {} : Failed \nError: Routes are  missing in RIB".format(tc_name)
 
-        step("Verify that highest AD nexthop are inactive")
+        step("TC11: Verify that highest AD nexthop are inactive")
         nh = []
         for nhp in range(2, 9):
             nh.append(NEXT_HOP_IP["nh" + str(nhp)][addr_type])
@@ -1623,9 +1594,9 @@ def test_static_route_delete_p0_tc11_ebgp(request):
         )
         assert (
             result is not True
-        ), "Testcase {} : Failed \nError: Routes " " are missing in RIB".format(tc_name)
+        ), "Testcase {} : Failed \nError: Routes   are missing in RIB".format(tc_name)
 
-    step("Configure redistribute static in BGP on R2 router")
+    step("TC11: Configure redistribute static in BGP on R2 router")
     for addr_type in ADDR_TYPES:
         input_dict_2 = {
             "r2": {
@@ -1643,7 +1614,7 @@ def test_static_route_delete_p0_tc11_ebgp(request):
             tc_name, result
         )
 
-    step("Remove the redistribute static knob")
+    step("TC11: Remove the redistribute static knob")
     for addr_type in ADDR_TYPES:
         input_dict_2 = {
             "r2": {
@@ -1677,7 +1648,7 @@ def test_static_route_delete_p0_tc11_ebgp(request):
         )
         assert (
             result is not True
-        ), "Testcase {} : Failed \nError: Routes are" " still present in RIB".format(
+        ), "Testcase {} : Failed \nError: Routes are  still present in RIB".format(
             tc_name
         )
 
@@ -1748,7 +1719,7 @@ def test_static_route_delete_p0_tc11_ebgp(request):
         )
         assert (
             result is not True
-        ), "Testcase {} : Failed \nError: Routes are" " still active in RIB".format(
+        ), "Testcase {} : Failed \nError: Routes are  still active in RIB".format(
             tc_name
         )
 
