@@ -1,24 +1,11 @@
 #!/usr/bin/python
+# SPDX-License-Identifier: ISC
 
 #
 # Copyright (c) 2020 by VMware, Inc. ("VMware")
 # Used Copyright (c) 2018 by Network Device Education Foundation,
 # Inc. ("NetDEF") in this file.
 #
-# Permission to use, copy, modify, and/or distribute this software
-# for any purpose with or without fee is hereby granted, provided
-# that the above copyright notice and this permission notice appear
-# in all copies.
-#
-# THE SOFTWARE IS PROVIDED "AS IS" AND VMWARE DISCLAIMS ALL WARRANTIES
-# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL VMWARE BE LIABLE FOR
-# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY
-# DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
-# WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
-# ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE
-# OF THIS SOFTWARE.
-#
 """
     -Verify static route ECMP functionality with 8 next hop
 
@@ -146,7 +133,7 @@ def setup_module(mod):
     logger.info("Running setup_module() done")
 
 
-def teardown_module(mod):
+def teardown_module():
     """
     Teardown the pytest environment
 
@@ -274,7 +261,7 @@ def test_staticroute_with_ecmp_p0_tc3_ibgp(request):
         )
         assert (
             result is True
-        ), "Testcase {} : Failed \nError: Routes are" " missing in RIB".format(tc_name)
+        ), "Testcase {} : Failed \nError: Routes are  missing in RIB".format(tc_name)
     step("Configure redistribute static in BGP on R2 router")
     for addr_type in ADDR_TYPES:
         input_dict_2 = {
@@ -329,11 +316,11 @@ def test_staticroute_with_ecmp_p0_tc3_ibgp(request):
         )
         assert (
             result is not True
-        ), "Testcase {} : Failed \nError: Routes are" " still present in RIB".format(
+        ), "Testcase {} : Failed \nError: Routes are  still present in RIB".format(
             tc_name
         )
 
-    step("Configure the static route with nexthop N1 to N8, one by" "one")
+    step("Configure the static route with nexthop N1 to N8, one by one")
 
     for addr_type in ADDR_TYPES:
         # add static routes
@@ -360,7 +347,7 @@ def test_staticroute_with_ecmp_p0_tc3_ibgp(request):
     )
     assert (
         result is True
-    ), "Testcase {} : Failed \nError: Routes are" " missing in RIB".format(tc_name)
+    ), "Testcase {} : Failed \nError: Routes are  missing in RIB".format(tc_name)
 
     step("Random shut of the nexthop interfaces")
     randnum = random.randint(0, 7)
@@ -389,7 +376,7 @@ def test_staticroute_with_ecmp_p0_tc3_ibgp(request):
         )
         assert (
             result is not True
-        ), "Testcase {} : Failed \n" "Error: Routes are still present in RIB".format(
+        ), "Testcase {} : Failed \n Error: Routes are still present in RIB".format(
             tc_name
         )
 
@@ -403,7 +390,7 @@ def test_staticroute_with_ecmp_p0_tc3_ibgp(request):
         )
         assert (
             result is True
-        ), "Testcase {} : Failed \n" "Error: Routes are missing in RIB".format(tc_name)
+        ), "Testcase {} : Failed \n Error: Routes are missing in RIB".format(tc_name)
 
     step("Reload the FRR router")
     # stop/start -> restart FRR router and verify
@@ -415,7 +402,7 @@ def test_staticroute_with_ecmp_p0_tc3_ibgp(request):
     )
     assert (
         result is True
-    ), "Testcase {} : Failed \nError: Routes are" " missing in RIB".format(tc_name)
+    ), "Testcase {} : Failed \nError: Routes are  missing in RIB".format(tc_name)
 
     write_test_footer(tc_name)
 
@@ -604,11 +591,9 @@ def test_staticroute_with_ecmp_with_diff_AD_p0_tc4_ibgp(request):
     )
     assert (
         result is not True
-    ), "Testcase {} : Failed \nError: Routes are" " still present in RIB".format(
-        tc_name
-    )
+    ), "Testcase {} : Failed \nError: Routes are  still present in RIB".format(tc_name)
 
-    step("Configure the static route with nexthop N1 to N8, one by" "one")
+    step("Configure the static route with nexthop N1 to N8, one by one")
     for addr_type in ADDR_TYPES:
         # add static routes
         for nhp in range(1, 9):
@@ -697,7 +682,7 @@ def test_staticroute_with_ecmp_with_diff_AD_p0_tc4_ibgp(request):
         )
         assert (
             result is not True
-        ), "Testcase {} : Failed \n" "Error: Routes are still present in RIB".format(
+        ), "Testcase {} : Failed \n Error: Routes are still present in RIB".format(
             tc_name
         )
 
@@ -711,7 +696,7 @@ def test_staticroute_with_ecmp_with_diff_AD_p0_tc4_ibgp(request):
         )
         assert (
             result is True
-        ), "Testcase {} : Failed \n" "Error: Routes are missing in RIB".format(tc_name)
+        ), "Testcase {} : Failed \n Error: Routes are missing in RIB".format(tc_name)
 
     step("Reload the FRR router")
     # stop/start -> restart FRR router and verify
@@ -865,7 +850,7 @@ def test_bgp_local_nexthop_p1_tc14_ibgp(request):
         result = verify_rib(tgen, addr_type, dut, input_dict_4)
         assert (
             result is True
-        ), "Testcase {} : Failed \nError: Routes is" " missing in RIB of R2".format(
+        ), "Testcase {} : Failed \nError:  routes are  missing in RIB of R2".format(
             tc_name
         )
 
@@ -873,13 +858,13 @@ def test_bgp_local_nexthop_p1_tc14_ibgp(request):
         dut = "r3"
         result = verify_bgp_rib(tgen, addr_type, dut, input_dict_4, expected=False)
         assert result is not True, (
-            "Testcase {} : Failed \nError: Routes is"
+            "Testcase {} : Failed \nError:  routes are"
             " still present in BGP RIB of R2".format(tc_name)
         )
 
         result = verify_rib(tgen, addr_type, dut, input_dict_4, expected=False)
         assert result is not True, (
-            "Testcase {} : Failed \nError: Routes is"
+            "Testcase {} : Failed \nError:  routes are"
             " still present in RIB of R2".format(tc_name)
         )
 
