@@ -405,14 +405,6 @@ static int netlink_information_fetch(struct nlmsghdr *h, ns_id_t ns_id,
 		return netlink_route_change(h, ns_id, startup);
 	case RTM_DELROUTE:
 		return netlink_route_change(h, ns_id, startup);
-	case RTM_NEWLINK:
-		return netlink_link_change(h, ns_id, startup);
-	case RTM_DELLINK:
-		return 0;
-	case RTM_NEWNEIGH:
-	case RTM_DELNEIGH:
-	case RTM_GETNEIGH:
-		return netlink_neigh_change(h, ns_id);
 	case RTM_NEWRULE:
 		return netlink_rule_change(h, ns_id, startup);
 	case RTM_DELRULE:
@@ -430,10 +422,6 @@ static int netlink_information_fetch(struct nlmsghdr *h, ns_id_t ns_id,
 	case RTM_NEWTFILTER:
 	case RTM_DELTFILTER:
 		return netlink_tfilter_change(h, ns_id, startup);
-	case RTM_NEWVLAN:
-		return netlink_vlan_change(h, ns_id, startup);
-	case RTM_DELVLAN:
-		return netlink_vlan_change(h, ns_id, startup);
 
 	/* Messages we may receive, but ignore */
 	case RTM_NEWCHAIN:
@@ -442,6 +430,8 @@ static int netlink_information_fetch(struct nlmsghdr *h, ns_id_t ns_id,
 		return 0;
 
 	/* Messages handled in the dplane thread */
+	case RTM_NEWLINK:
+	case RTM_DELLINK:
 	case RTM_NEWADDR:
 	case RTM_DELADDR:
 	case RTM_NEWNETCONF:
@@ -449,6 +439,11 @@ static int netlink_information_fetch(struct nlmsghdr *h, ns_id_t ns_id,
 	case RTM_NEWTUNNEL:
 	case RTM_DELTUNNEL:
 	case RTM_GETTUNNEL:
+	case RTM_NEWVLAN:
+	case RTM_DELVLAN:
+	case RTM_NEWNEIGH:
+	case RTM_DELNEIGH:
+	case RTM_GETNEIGH:
 		return 0;
 	default:
 		/*
@@ -492,6 +487,14 @@ static int dplane_netlink_information_fetch(struct nlmsghdr *h, ns_id_t ns_id,
 	case RTM_DELLINK:
 		return netlink_link_change(h, ns_id, startup);
 
+	case RTM_NEWVLAN:
+	case RTM_DELVLAN:
+		return netlink_vlan_change(h, ns_id, startup);
+
+	case RTM_NEWNEIGH:
+	case RTM_DELNEIGH:
+	case RTM_GETNEIGH:
+		return netlink_neigh_change(h, ns_id);
 	default:
 		break;
 	}
@@ -932,7 +935,7 @@ static int netlink_recv_msg(struct nlsock *nl, struct msghdr *msg)
 	} while (status == -1 && errno == EINTR);
 
 	if (status == -1) {
-		if (errno == EWOULDBLOCK || errno == EAGAIN)
+		if (errno == EWOULDBLOCK || errno == EAGAIN || errno == EMSGSIZE)
 			return 0;
 		flog_err(EC_ZEBRA_RECVMSG_OVERRUN, "%s recvmsg overrun: %s",
 			 nl->name, safe_strerror(errno));
@@ -940,7 +943,7 @@ static int netlink_recv_msg(struct nlsock *nl, struct msghdr *msg)
 		 * In this case we are screwed. There is no good way to recover
 		 * zebra at this point.
 		 */
-		exit(-1);
+		frr_exit_with_buffer_flush(-1);
 	}
 
 	if (status == 0) {
@@ -1621,6 +1624,7 @@ static enum netlink_msg_status nl_put_msg(struct nl_batch *bth,
 	case DPLANE_OP_IPSET_ENTRY_ADD:
 	case DPLANE_OP_IPSET_ENTRY_DELETE:
 	case DPLANE_OP_STARTUP_STAGE:
+	case DPLANE_OP_VLAN_INSTALL:
 		return FRR_NETLINK_ERROR;
 
 	case DPLANE_OP_GRE_SET:
@@ -1771,17 +1775,14 @@ void kernel_init(struct zebra_ns *zns)
 	 * exist.
 	 */
 	groups = RTMGRP_IPV4_ROUTE | RTMGRP_IPV6_ROUTE | RTMGRP_IPV4_MROUTE |
-		 RTMGRP_NEIGH | ((uint32_t)1 << (RTNLGRP_IPV4_RULE - 1)) |
+		 ((uint32_t)1 << (RTNLGRP_IPV4_RULE - 1)) |
 		 ((uint32_t)1 << (RTNLGRP_IPV6_RULE - 1)) |
-		 ((uint32_t)1 << (RTNLGRP_NEXTHOP - 1)) |
-		 ((uint32_t)1 << (RTNLGRP_TC - 1));
+		 ((uint32_t)1 << (RTNLGRP_NEXTHOP - 1)) | ((uint32_t)1 << (RTNLGRP_TC - 1));
 
-	dplane_groups = (RTMGRP_LINK            |
-			 RTMGRP_IPV4_IFADDR     |
-			 RTMGRP_IPV6_IFADDR     |
-			 ((uint32_t) 1 << (RTNLGRP_IPV4_NETCONF - 1)) |
-			 ((uint32_t) 1 << (RTNLGRP_IPV6_NETCONF - 1)) |
-			 ((uint32_t) 1 << (RTNLGRP_MPLS_NETCONF - 1)));
+	dplane_groups = (RTMGRP_LINK | RTMGRP_NEIGH | RTMGRP_IPV4_IFADDR | RTMGRP_IPV6_IFADDR |
+			 ((uint32_t)1 << (RTNLGRP_IPV4_NETCONF - 1)) |
+			 ((uint32_t)1 << (RTNLGRP_IPV6_NETCONF - 1)) |
+			 ((uint32_t)1 << (RTNLGRP_MPLS_NETCONF - 1)));
 
 	/* Use setsockopt for > 31 group */
 	ext_groups = RTNLGRP_TUNNEL;
@@ -1793,7 +1794,7 @@ void kernel_init(struct zebra_ns *zns)
 			   NETLINK_ROUTE) < 0) {
 		zlog_err("Failure to create %s socket",
 			 zns->netlink.name);
-		exit(-1);
+		frr_exit_with_buffer_flush(-1);
 	}
 
 	kernel_netlink_nlsock_insert(&zns->netlink);
@@ -1805,7 +1806,7 @@ void kernel_init(struct zebra_ns *zns)
 			   NETLINK_ROUTE) < 0) {
 		zlog_err("Failure to create %s socket",
 			 zns->netlink_cmd.name);
-		exit(-1);
+		frr_exit_with_buffer_flush(-1);
 	}
 
 	kernel_netlink_nlsock_insert(&zns->netlink_cmd);
@@ -1819,7 +1820,7 @@ void kernel_init(struct zebra_ns *zns)
 			   NETLINK_ROUTE) < 0) {
 		zlog_err("Failure to create %s socket",
 			 zns->netlink_dplane_out.name);
-		exit(-1);
+		frr_exit_with_buffer_flush(-1);
 	}
 
 	kernel_netlink_nlsock_insert(&zns->netlink_dplane_out);
@@ -1833,7 +1834,7 @@ void kernel_init(struct zebra_ns *zns)
 			   zns->ns_id, NETLINK_ROUTE) < 0) {
 		zlog_err("Failure to create %s socket",
 			 zns->netlink_dplane_in.name);
-		exit(-1);
+		frr_exit_with_buffer_flush(-1);
 	}
 
 	kernel_netlink_nlsock_insert(&zns->netlink_dplane_in);
@@ -1862,8 +1863,8 @@ void kernel_init(struct zebra_ns *zns)
 	 * setsockopt multicast group subscriptions that don't fit in nl_groups
 	 */
 	grp = RTNLGRP_BRVLAN;
-	ret = setsockopt(zns->netlink.sock, SOL_NETLINK, NETLINK_ADD_MEMBERSHIP,
-			 &grp, sizeof(grp));
+	ret = setsockopt(zns->netlink_dplane_in.sock, SOL_NETLINK,
+			 NETLINK_ADD_MEMBERSHIP, &grp, sizeof(grp));
 
 	if (ret < 0)
 		zlog_notice(
@@ -1982,7 +1983,7 @@ static void kernel_nlsock_fini(struct nlsock *nls)
 
 void kernel_terminate(struct zebra_ns *zns, bool complete)
 {
-	EVENT_OFF(zns->t_netlink);
+	event_cancel(&zns->t_netlink);
 
 	kernel_nlsock_fini(&zns->netlink);
 
@@ -1995,11 +1996,8 @@ void kernel_terminate(struct zebra_ns *zns, bool complete)
 	/* During zebra shutdown, we need to leave the dataplane socket
 	 * around until all work is done.
 	 */
-	if (complete) {
+	if (complete)
 		kernel_nlsock_fini(&zns->netlink_dplane_out);
-
-		XFREE(MTYPE_NL_BUF, nl_batch_tx_buf);
-	}
 }
 
 /*
@@ -2019,6 +2017,8 @@ void kernel_router_init(void)
  */
 void kernel_router_terminate(void)
 {
+	XFREE(MTYPE_NL_BUF, nl_batch_tx_buf);
+
 	pthread_mutex_destroy(&nlsock_mutex);
 
 	hash_free(nlsock_hash);
