@@ -1337,6 +1337,12 @@ static void rtadv_prefix_reset(struct zebra_if *zif, struct rtadv_prefix *rp,
 			if (rprefix->AdvPrefixCreate == PREFIX_SRC_BOTH) {
 				rprefix->AdvPrefixCreate = PREFIX_SRC_MANUAL;
 				return;
+			} else if (rprefix->AdvPrefixCreate == PREFIX_SRC_MANUAL) {
+				/*
+				 * The address might not be added, so jump
+				 * out here.
+				 */
+				return;
 			}
 		}
 
@@ -2282,6 +2288,6 @@ void rtadv_init(void)
 		zlog_debug("%s: RTADV_ADATA_SIZE chosen will not work on this platform, please use a larger size",
 			   __func__);
 
-		exit(-1);
+		frr_exit_with_buffer_flush(-1);
 	}
 }
