@@ -261,7 +261,7 @@ static int netlink_route_info_fill(struct netlink_route_info *ri, int cmd,
 	ri->prefix = rib_dest_prefix(dest);
 	ri->af = rib_dest_af(dest);
 
-	ri->nlmsg_pid = pid;
+	ri->nlmsg_pid = zebra_pid;
 
 	ri->nlmsg_type = cmd;
 	ri->rtm_protocol = RTPROT_UNSPEC;
@@ -285,7 +285,7 @@ static int netlink_route_info_fill(struct netlink_route_info *ri, int cmd,
 	ri->metric = &re->metric;
 
 	for (ALL_NEXTHOPS(re->nhe->nhg, nexthop)) {
-		if (ri->num_nhs >= zrouter.multipath_num)
+		if (ri->num_nhs >= zrouter.zav.multipath_num)
 			break;
 
 		if (CHECK_FLAG(nexthop->flags, NEXTHOP_FLAG_RECURSIVE))
@@ -592,19 +592,19 @@ int zfpm_netlink_encode_mac(struct fpm_mac_info_t *mac, char *in_buf,
 				RTM_DELNEIGH : RTM_NEWNEIGH;
 	req->hdr.nlmsg_flags = NLM_F_REQUEST;
 	if (req->hdr.nlmsg_type == RTM_NEWNEIGH)
-		req->hdr.nlmsg_flags |= (NLM_F_CREATE | NLM_F_REPLACE);
+		SET_FLAG(req->hdr.nlmsg_flags, (NLM_F_CREATE | NLM_F_REPLACE));
 
 	/* Construct ndmsg */
 	req->ndm.ndm_family = AF_BRIDGE;
 	req->ndm.ndm_ifindex = mac->vxlan_if;
 
 	req->ndm.ndm_state = NUD_REACHABLE;
-	req->ndm.ndm_flags |= NTF_SELF | NTF_MASTER;
+	SET_FLAG(req->ndm.ndm_flags, (NTF_SELF | NTF_MASTER));
 	if (CHECK_FLAG(mac->zebra_flags,
 		(ZEBRA_MAC_STICKY | ZEBRA_MAC_REMOTE_DEF_GW)))
-		req->ndm.ndm_state |= NUD_NOARP;
+		SET_FLAG(req->ndm.ndm_state, NUD_NOARP);
 	else
-		req->ndm.ndm_flags |= NTF_EXT_LEARNED;
+		SET_FLAG(req->ndm.ndm_flags, NTF_EXT_LEARNED);
 
 	/* Add attributes */
 	nl_attr_put(&req->hdr, in_buf_len, NDA_LLADDR, &mac->macaddr, 6);
