@@ -1,25 +1,10 @@
+// SPDX-License-Identifier: GPL-2.0-or-later
 /*
  * zebra_fpm_protobuf.c
  *
  * @copyright Copyright (C) 2016 Sproute Networks, Inc.
  *
  * @author Avneesh Sachdev <avneesh@sproute.com>
- *
- * This file is part of Quagga.
- *
- * Quagga is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 2, or (at your option) any
- * later version.
- *
- * Quagga is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; see the file COPYING; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 #include <zebra.h>
 
@@ -174,7 +159,7 @@ static Fpm__AddRoute *create_add_route_message(qpb_allocator_t *allocator,
 	 */
 	num_nhs = 0;
 	for (ALL_NEXTHOPS(re->nhe->nhg, nexthop)) {
-		if (num_nhs >= zrouter.multipath_num)
+		if (num_nhs >= zrouter.zav.multipath_num)
 			break;
 
 		if (num_nhs >= array_size(nexthops))
@@ -186,7 +171,8 @@ static Fpm__AddRoute *create_add_route_message(qpb_allocator_t *allocator,
 				msg->route_type = FPM__ROUTE_TYPE__UNREACHABLE;
 				break;
 			case BLACKHOLE_NULL:
-			default:
+			case BLACKHOLE_UNSPEC:
+			case BLACKHOLE_ADMINPROHIB:
 				msg->route_type = FPM__ROUTE_TYPE__BLACKHOLE;
 				break;
 			}
