@@ -14,9 +14,7 @@ const char *features[] = {
 #if HAVE_BFDD == 0
 	"ptm-bfd",
 #endif
-#if defined(HAVE_RTADV)
 	"ipv6-router-advertisements",
-#endif
 	NULL
 };
 
@@ -25,6 +23,12 @@ const struct frr_yang_module_info frr_zebra_info = {
 	.name = "frr-zebra",
 	.features = features,
 	.nodes = {
+		{
+			.xpath = "/frr-zebra:zebra/state/max-multipath",
+			.cbs = {
+				.get_elem = zebra_max_multipath_get_elem,
+			}
+		},
 		{
 			.xpath = "/frr-zebra:zebra/ip-forwarding",
 			.cbs = {
@@ -32,6 +36,12 @@ const struct frr_yang_module_info frr_zebra_info = {
 				.destroy = zebra_ip_forwarding_destroy,
 			}
 		},
+		{
+			.xpath = "/frr-zebra:zebra/state/ip-forwarding",
+			.cbs = {
+				.get_elem = zebra_ip_forwarding_get_elem,
+			}
+		},
 		{
 			.xpath = "/frr-zebra:zebra/ipv6-forwarding",
 			.cbs = {
@@ -39,6 +49,18 @@ const struct frr_yang_module_info frr_zebra_info = {
 				.destroy = zebra_ipv6_forwarding_destroy,
 			}
 		},
+		{
+			.xpath = "/frr-zebra:zebra/state/ipv6-forwarding",
+			.cbs = {
+				.get_elem = zebra_ipv6_forwarding_get_elem,
+			}
+		},
+		{
+			.xpath = "/frr-zebra:zebra/state/mpls-forwarding",
+			.cbs = {
+				.get_elem = zebra_state_mpls_forwarding_get_elem,
+			}
+		},
 		{
 			.xpath = "/frr-zebra:zebra/workqueue-hold-timer",
 			.cbs = {
@@ -579,7 +601,6 @@ const struct frr_yang_module_info frr_zebra_info = {
 				.modify = lib_interface_zebra_evpn_mh_uplink_modify,
 			}
 		},
-#if defined(HAVE_RTADV)
 		{
 			.xpath = "/frr-interface:lib/interface/frr-zebra:zebra/ipv6-router-advertisements/send-advertisements",
 			.cbs = {
@@ -739,7 +760,20 @@ const struct frr_yang_module_info frr_zebra_info = {
 				.destroy = lib_interface_zebra_ipv6_router_advertisements_rdnss_rdnss_address_lifetime_destroy,
 			}
 		},
-#endif /* defined(HAVE_RTADV) */
+		{
+			.xpath = "/frr-interface:lib/interface/frr-zebra:zebra/ipv6-router-advertisements/pref64/pref64-prefix",
+			.cbs = {
+				.create = lib_interface_zebra_ipv6_router_advertisements_pref64_pref64_prefix_create,
+				.destroy = lib_interface_zebra_ipv6_router_advertisements_pref64_pref64_prefix_destroy,
+			}
+		},
+		{
+			.xpath = "/frr-interface:lib/interface/frr-zebra:zebra/ipv6-router-advertisements/pref64/pref64-prefix/lifetime",
+			.cbs = {
+				.modify = lib_interface_zebra_ipv6_router_advertisements_pref64_pref64_prefix_lifetime_modify,
+				.destroy = lib_interface_zebra_ipv6_router_advertisements_pref64_pref64_prefix_lifetime_destroy,
+			}
+		},
 #if HAVE_BFDD == 0
 		{
 			.xpath = "/frr-interface:lib/interface/frr-zebra:zebra/ptm-enable",
@@ -1077,6 +1111,12 @@ const struct frr_yang_module_info frr_zebra_info = {
 				.get_elem = lib_vrf_zebra_ribs_rib_route_route_entry_nexthop_group_nexthop_srv6_segs_stack_entry_seg_get_elem,
 			}
 		},
+		{
+			.xpath = "/frr-vrf:lib/vrf/frr-zebra:zebra/ribs/rib/route/route-entry/nexthop-group/nexthop/srv6-segs-stack/encap-behavior",
+			.cbs = {
+				.get_elem = lib_vrf_zebra_ribs_rib_route_route_entry_nexthop_group_nexthop_srv6_segs_stack_encap_behavior_get_elem,
+			}
+		},
 
 		{
 			.xpath = "/frr-vrf:lib/vrf/frr-zebra:zebra/ribs/rib/route/route-entry/nexthop-group/nexthop/mpls-label-stack/entry",
