@@ -14,6 +14,7 @@
 #include "libfrr.h"
 #include "lib/command.h"
 #include "lib/routemap.h"
+#include "zebra/rtadv.h"
 #include "zebra/zebra_nb.h"
 #include "zebra/rib.h"
 #include "zebra_nb.h"
@@ -29,19 +30,28 @@
 #include "zebra/zebra_routemap.h"
 #include "zebra/zebra_rnh.h"
 #include "zebra/table_manager.h"
+#include "zebra/ipforward.h"
 
 /*
  * XPath: /frr-zebra:zebra/ip-forwarding
  */
 int zebra_ip_forwarding_modify(struct nb_cb_modify_args *args)
 {
-	switch (args->event) {
-	case NB_EV_VALIDATE:
-	case NB_EV_PREPARE:
-	case NB_EV_ABORT:
-	case NB_EV_APPLY:
-		/* TODO: implement me. */
-		break;
+	bool forwarding;
+	int ret;
+
+	if (args->event != NB_EV_APPLY)
+		return NB_OK;
+
+	forwarding = yang_dnode_get_bool(args->dnode, NULL);
+
+	ret = ipforward();
+	if (ret == 0) {
+		if (forwarding)
+			ipforward_on();
+	} else {
+		if (!forwarding)
+			ipforward_off();
 	}
 
 	return NB_OK;
@@ -66,13 +76,21 @@ int zebra_ip_forwarding_destroy(struct nb_cb_destroy_args *args)
  */
 int zebra_ipv6_forwarding_modify(struct nb_cb_modify_args *args)
 {
-	switch (args->event) {
-	case NB_EV_VALIDATE:
-	case NB_EV_PREPARE:
-	case NB_EV_ABORT:
-	case NB_EV_APPLY:
-		/* TODO: implement me. */
-		break;
+	bool forwarding;
+	int ret;
+
+	if (args->event != NB_EV_APPLY)
+		return NB_OK;
+
+	forwarding = yang_dnode_get_bool(args->dnode, NULL);
+	ret = ipforward_ipv6();
+
+	if (ret == 0) {
+		if (forwarding)
+			ipforward_ipv6_on();
+	} else {
+		if (!forwarding)
+			ipforward_ipv6_off();
 	}
 
 	return NB_OK;
@@ -856,6 +874,7 @@ int lib_interface_zebra_ipv4_addrs_create(struct nb_cb_create_args *args)
 	struct interface *ifp;
 	struct prefix p;
 	const char *label = NULL;
+	bool martian_ok;
 
 	p.family = AF_INET;
 	yang_dnode_get_ipv4(&p.u.prefix4, args->dnode, "ip");
@@ -866,9 +885,10 @@ int lib_interface_zebra_ipv4_addrs_create(struct nb_cb_create_args *args)
 
 	switch (args->event) {
 	case NB_EV_VALIDATE:
-		if (ipv4_martian(&p.u.prefix4)) {
-			snprintfrr(args->errmsg, args->errmsg_len,
-				   "invalid address %pFX", &p);
+		martian_ok = yang_dnode_get_bool(args->dnode,
+						 "/frr-host:host/allow-reserved-ranges");
+		if (!martian_ok && ipv4_martian(&p.u.prefix4)) {
+			snprintfrr(args->errmsg, args->errmsg_len, "invalid address %pFX", &p);
 			return NB_ERR_VALIDATION;
 		}
 		break;
@@ -2525,7 +2545,6 @@ int lib_interface_zebra_evpn_mh_uplink_modify(struct nb_cb_modify_args *args)
 	return NB_OK;
 }
 
-#if defined(HAVE_RTADV)
 /*
  * XPath: /frr-interface:lib/interface/frr-zebra:zebra/ipv6-router-advertisements/send-advertisements
  */
@@ -3248,7 +3267,85 @@ int lib_interface_zebra_ipv6_router_advertisements_dnssl_dnssl_domain_lifetime_d
 
 	return NB_OK;
 }
-#endif /* defined(HAVE_RTADV) */
+
+/*
+ * XPath: /frr-interface:lib/interface/frr-zebra:zebra/ipv6-router-advertisements/pref64/pref64-prefix
+ */
+int lib_interface_zebra_ipv6_router_advertisements_pref64_pref64_prefix_create(
+	struct nb_cb_create_args *args)
+{
+	struct interface *ifp;
+	struct pref64_adv *entry;
+	struct prefix_ipv6 p;
+	uint32_t lifetime = PREF64_LIFETIME_AUTO;
+
+	if (args->event != NB_EV_APPLY)
+		return NB_OK;
+
+	ifp = nb_running_get_entry(args->dnode, NULL, true);
+
+	yang_dnode_get_ipv6p(&p, args->dnode, "prefix");
+
+	if (yang_dnode_exists(args->dnode, "lifetime"))
+		lifetime = yang_dnode_get_uint16(args->dnode, "lifetime");
+
+	entry = rtadv_pref64_set(ifp->info, &p, lifetime);
+	nb_running_set_entry(args->dnode, entry);
+
+	return NB_OK;
+}
+
+int lib_interface_zebra_ipv6_router_advertisements_pref64_pref64_prefix_destroy(
+	struct nb_cb_destroy_args *args)
+{
+	struct interface *ifp;
+	struct pref64_adv *entry;
+
+	if (args->event != NB_EV_APPLY)
+		return NB_OK;
+
+	entry = nb_running_unset_entry(args->dnode);
+	ifp = nb_running_get_entry(args->dnode, NULL, true);
+
+	rtadv_pref64_reset(ifp->info, entry);
+
+	return NB_OK;
+}
+
+/*
+ * XPath: /frr-interface:lib/interface/frr-zebra:zebra/ipv6-router-advertisements/rdnss/rdnss-address/lifetime
+ */
+int lib_interface_zebra_ipv6_router_advertisements_pref64_pref64_prefix_lifetime_modify(
+	struct nb_cb_modify_args *args)
+{
+	struct interface *ifp;
+	struct pref64_adv *entry;
+
+	if (args->event != NB_EV_APPLY)
+		return NB_OK;
+
+	entry = nb_running_get_entry(args->dnode, NULL, true);
+	ifp = nb_running_get_entry(lyd_parent(lyd_parent(args->dnode)), NULL, true);
+
+	rtadv_pref64_update(ifp->info, entry, yang_dnode_get_uint16(args->dnode, NULL));
+	return NB_OK;
+}
+
+int lib_interface_zebra_ipv6_router_advertisements_pref64_pref64_prefix_lifetime_destroy(
+	struct nb_cb_destroy_args *args)
+{
+	struct interface *ifp;
+	struct pref64_adv *entry;
+
+	if (args->event != NB_EV_APPLY)
+		return NB_OK;
+
+	entry = nb_running_get_entry(args->dnode, NULL, true);
+	ifp = nb_running_get_entry(lyd_parent(lyd_parent(args->dnode)), NULL, true);
+
+	rtadv_pref64_update(ifp->info, entry, PREF64_LIFETIME_AUTO);
+	return NB_OK;
+}
 
 #if HAVE_BFDD == 0
 /*
