@@ -7,6 +7,7 @@
 
 #include <pthread.h>
 #include "lib/frratomic.h"
+#include "lib/hook.h"
 
 #include "zebra_router.h"
 #include "zebra_pbr.h"
@@ -23,9 +24,11 @@ DEFINE_MTYPE_STATIC(ZEBRA, RIB_TABLE_INFO, "RIB table info");
 DEFINE_MTYPE_STATIC(ZEBRA, ZEBRA_RT_TABLE, "Zebra VRF table");
 
 struct zebra_router zrouter = {
-	.multipath_num = MULTIPATH_NUM,
+	.zav.multipath_num = MULTIPATH_NUM,
 };
 
+DEFINE_HOOK(nos_initialize_data, (struct zebra_architectural_values *zav), (zav));
+
 static inline int
 zebra_router_table_entry_compare(const struct zebra_router_table *e1,
 				 const struct zebra_router_table *e2);
@@ -275,11 +278,11 @@ void zebra_router_terminate(void)
 
 bool zebra_router_notify_on_ack(void)
 {
-	return !zrouter.asic_offloaded || zrouter.notify_on_ack;
+	return !zrouter.zav.asic_offloaded || zrouter.zav.notify_on_ack;
 }
 
-void zebra_router_init(bool asic_offload, bool notify_on_ack,
-		       bool v6_with_v4_nexthop)
+void zebra_router_init(bool asic_offload, bool notify_on_ack, bool v6_with_v4_nexthop,
+		       bool nexthop_weight_16_bit)
 {
 	zrouter.sequence_num = 0;
 
@@ -336,9 +339,11 @@ void zebra_router_init(bool asic_offload, bool notify_on_ack,
 					       zebra_tc_filter_hash_equal,
 					       "TC (filter) Hash");
 
-	zrouter.asic_offloaded = asic_offload;
-	zrouter.notify_on_ack = notify_on_ack;
-	zrouter.v6_with_v4_nexthop = v6_with_v4_nexthop;
+	zrouter.zav.asic_offloaded = asic_offload;
+	zrouter.zav.notify_on_ack = notify_on_ack;
+	zrouter.zav.v6_with_v4_nexthop = v6_with_v4_nexthop;
+	zrouter.zav.nexthop_weight_is_16bit = nexthop_weight_16_bit;
+
 	/*
 	 * If you start using asic_notification_nexthop_control
 	 * come talk to the FRR community about what you are doing
@@ -348,9 +353,16 @@ void zebra_router_init(bool asic_offload, bool notify_on_ack,
 	CPP_NOTICE(
 		"Remove zrouter.asic_notification_nexthop_control as that it's not being maintained or used");
 #endif
-	zrouter.asic_notification_nexthop_control = false;
+	zrouter.zav.asic_notification_nexthop_control = false;
 
-	zrouter.nexthop_weight_scale_value = 254;
+	zrouter.backup_nhs_installed = false;
+
+	hook_call(nos_initialize_data, &zrouter.zav);
+
+	if (!zrouter.zav.nexthop_weight_is_16bit)
+		zrouter.nexthop_weight_scale_value = 255;
+	else
+		zrouter.nexthop_weight_scale_value = 0xFFFF;
 
 #ifdef HAVE_SCRIPTING
 	zebra_script_init();
