@@ -7,6 +7,7 @@
 #define __ZEBRA_ROUTER_H__
 
 #include "lib/mlag.h"
+#include "lib/hook.h"
 
 #include "zebra/zebra_ns.h"
 #include "zebra/zebra_vrf.h"
@@ -117,6 +118,32 @@ struct zebra_mlag_info {
 #define RTADV_TIMER_WHEEL_SLOTS_NO  100
 #define ICMPV6_JOIN_TIMER_EXP_MS    100
 
+/*
+ * These are values that are changeable due to some architectural restrictions
+ * of the underlying NOS's actual data plane.  They are sequestered into
+ * their own area such that we don't necessarily want to expose all of zebra_router
+ */
+struct zebra_architectural_values {
+	uint32_t multipath_num;
+
+	bool asic_offloaded;
+	bool notify_on_ack;
+	bool v6_with_v4_nexthop;
+	bool v6_rr_semantics;
+
+	bool supports_nhgs;
+
+	/*
+	 * If the asic is notifying us about successful nexthop
+	 * allocation/control.  Some developers have made their
+	 * asic take control of how many nexthops/ecmp they can
+	 * have and will report what is successfull or not
+	 */
+	bool asic_notification_nexthop_control;
+	bool nexthop_weight_is_16bit;
+
+};
+
 struct zebra_router {
 	atomic_bool in_shutdown;
 
@@ -182,7 +209,7 @@ struct zebra_router {
 	 */
 	struct zebra_vrf *evpn_vrf;
 
-	uint32_t multipath_num;
+	struct zebra_architectural_values zav;
 
 	/*
 	 * zebra start time and time of sweeping RIB of old routes
@@ -202,25 +229,6 @@ struct zebra_router {
 	struct hash *nhgs;
 	struct hash *nhgs_id;
 
-	/*
-	 * Does the underlying system provide an asic offload
-	 */
-	bool asic_offloaded;
-	bool notify_on_ack;
-	bool v6_with_v4_nexthop;
-
-	bool v6_rr_semantics;
-
-	/*
-	 * If the asic is notifying us about successful nexthop
-	 * allocation/control.  Some developers have made their
-	 * asic take control of how many nexthops/ecmp they can
-	 * have and will report what is successfull or not
-	 */
-	bool asic_notification_nexthop_control;
-
-	bool supports_nhgs;
-
 	bool all_mc_forwardingv4, default_mc_forwardingv4;
 	bool all_mc_forwardingv6, default_mc_forwardingv6;
 	bool all_linkdownv4, default_linkdownv4;
@@ -235,6 +243,8 @@ struct zebra_router {
 	uint8_t protodown_r_bit;
 
 	uint64_t nexthop_weight_scale_value;
+
+	bool backup_nhs_installed;
 };
 
 #define GRACEFUL_RESTART_TIME 60
@@ -242,8 +252,8 @@ struct zebra_router {
 extern struct zebra_router zrouter;
 extern uint32_t rcvbufsize;
 
-extern void zebra_router_init(bool asic_offload, bool notify_on_ack,
-			      bool v6_with_v4_nexthop);
+extern void zebra_router_init(bool asic_offload, bool notify_on_ack, bool v6_with_v4_nexthop,
+			      bool nexthop_weight_16_bit);
 extern void zebra_router_cleanup(void);
 extern void zebra_router_terminate(void);
 
@@ -285,7 +295,7 @@ extern bool zebra_router_notify_on_ack(void);
 
 static inline void zebra_router_set_supports_nhgs(bool support)
 {
-	zrouter.supports_nhgs = support;
+	zrouter.zav.supports_nhgs = support;
 }
 
 static inline bool zebra_router_in_shutdown(void)
@@ -324,6 +334,8 @@ extern void zebra_main_router_started(void);
 /* zebra_northbound.c */
 extern const struct frr_yang_module_info frr_zebra_info;
 
+DECLARE_HOOK(nos_initialize_data, (struct zebra_architectural_values *), (zav));
+
 #ifdef __cplusplus
 }
 #endif
